#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class Coupon(object):

    def __init__(self):
        self._available_amount = None
        self._coupon_no = None
        self._deduct_amount = None
        self._gmt_active = None
        self._gmt_create = None
        self._gmt_expired = None
        self._instructions = None
        self._memo = None
        self._merchant_uniq_id = None
        self._multi_use_flag = None
        self._name = None
        self._refund_flag = None
        self._status = None
        self._template_no = None
        self._user_id = None

    @property
    def available_amount(self):
        return self._available_amount

    @available_amount.setter
    def available_amount(self, value):
        self._available_amount = value
    @property
    def coupon_no(self):
        return self._coupon_no

    @coupon_no.setter
    def coupon_no(self, value):
        self._coupon_no = value
    @property
    def deduct_amount(self):
        return self._deduct_amount

    @deduct_amount.setter
    def deduct_amount(self, value):
        self._deduct_amount = value
    @property
    def gmt_active(self):
        return self._gmt_active

    @gmt_active.setter
    def gmt_active(self, value):
        self._gmt_active = value
    @property
    def gmt_create(self):
        return self._gmt_create

    @gmt_create.setter
    def gmt_create(self, value):
        self._gmt_create = value
    @property
    def gmt_expired(self):
        return self._gmt_expired

    @gmt_expired.setter
    def gmt_expired(self, value):
        self._gmt_expired = value
    @property
    def instructions(self):
        return self._instructions

    @instructions.setter
    def instructions(self, value):
        self._instructions = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def merchant_uniq_id(self):
        return self._merchant_uniq_id

    @merchant_uniq_id.setter
    def merchant_uniq_id(self, value):
        self._merchant_uniq_id = value
    @property
    def multi_use_flag(self):
        return self._multi_use_flag

    @multi_use_flag.setter
    def multi_use_flag(self, value):
        self._multi_use_flag = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def refund_flag(self):
        return self._refund_flag

    @refund_flag.setter
    def refund_flag(self, value):
        self._refund_flag = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def template_no(self):
        return self._template_no

    @template_no.setter
    def template_no(self, value):
        self._template_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.available_amount:
            if hasattr(self.available_amount, 'to_alipay_dict'):
                params['available_amount'] = self.available_amount.to_alipay_dict()
            else:
                params['available_amount'] = self.available_amount
        if self.coupon_no:
            if hasattr(self.coupon_no, 'to_alipay_dict'):
                params['coupon_no'] = self.coupon_no.to_alipay_dict()
            else:
                params['coupon_no'] = self.coupon_no
        if self.deduct_amount:
            if hasattr(self.deduct_amount, 'to_alipay_dict'):
                params['deduct_amount'] = self.deduct_amount.to_alipay_dict()
            else:
                params['deduct_amount'] = self.deduct_amount
        if self.gmt_active:
            if hasattr(self.gmt_active, 'to_alipay_dict'):
                params['gmt_active'] = self.gmt_active.to_alipay_dict()
            else:
                params['gmt_active'] = self.gmt_active
        if self.gmt_create:
            if hasattr(self.gmt_create, 'to_alipay_dict'):
                params['gmt_create'] = self.gmt_create.to_alipay_dict()
            else:
                params['gmt_create'] = self.gmt_create
        if self.gmt_expired:
            if hasattr(self.gmt_expired, 'to_alipay_dict'):
                params['gmt_expired'] = self.gmt_expired.to_alipay_dict()
            else:
                params['gmt_expired'] = self.gmt_expired
        if self.instructions:
            if hasattr(self.instructions, 'to_alipay_dict'):
                params['instructions'] = self.instructions.to_alipay_dict()
            else:
                params['instructions'] = self.instructions
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.merchant_uniq_id:
            if hasattr(self.merchant_uniq_id, 'to_alipay_dict'):
                params['merchant_uniq_id'] = self.merchant_uniq_id.to_alipay_dict()
            else:
                params['merchant_uniq_id'] = self.merchant_uniq_id
        if self.multi_use_flag:
            if hasattr(self.multi_use_flag, 'to_alipay_dict'):
                params['multi_use_flag'] = self.multi_use_flag.to_alipay_dict()
            else:
                params['multi_use_flag'] = self.multi_use_flag
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.refund_flag:
            if hasattr(self.refund_flag, 'to_alipay_dict'):
                params['refund_flag'] = self.refund_flag.to_alipay_dict()
            else:
                params['refund_flag'] = self.refund_flag
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.template_no:
            if hasattr(self.template_no, 'to_alipay_dict'):
                params['template_no'] = self.template_no.to_alipay_dict()
            else:
                params['template_no'] = self.template_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = Coupon()
        if 'available_amount' in d:
            o.available_amount = d['available_amount']
        if 'coupon_no' in d:
            o.coupon_no = d['coupon_no']
        if 'deduct_amount' in d:
            o.deduct_amount = d['deduct_amount']
        if 'gmt_active' in d:
            o.gmt_active = d['gmt_active']
        if 'gmt_create' in d:
            o.gmt_create = d['gmt_create']
        if 'gmt_expired' in d:
            o.gmt_expired = d['gmt_expired']
        if 'instructions' in d:
            o.instructions = d['instructions']
        if 'memo' in d:
            o.memo = d['memo']
        if 'merchant_uniq_id' in d:
            o.merchant_uniq_id = d['merchant_uniq_id']
        if 'multi_use_flag' in d:
            o.multi_use_flag = d['multi_use_flag']
        if 'name' in d:
            o.name = d['name']
        if 'refund_flag' in d:
            o.refund_flag = d['refund_flag']
        if 'status' in d:
            o.status = d['status']
        if 'template_no' in d:
            o.template_no = d['template_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ContractStartInfoOpenApiVO import ContractStartInfoOpenApiVO


class AlipayBossContractGeneralCreateModel(object):

    def __init__(self):
        self._biz_no = None
        self._biz_source = None
        self._contract_list = None
        self._start_type = None

    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def biz_source(self):
        return self._biz_source

    @biz_source.setter
    def biz_source(self, value):
        self._biz_source = value
    @property
    def contract_list(self):
        return self._contract_list

    @contract_list.setter
    def contract_list(self, value):
        if isinstance(value, list):
            self._contract_list = list()
            for i in value:
                if isinstance(i, ContractStartInfoOpenApiVO):
                    self._contract_list.append(i)
                else:
                    self._contract_list.append(ContractStartInfoOpenApiVO.from_alipay_dict(i))
    @property
    def start_type(self):
        return self._start_type

    @start_type.setter
    def start_type(self, value):
        self._start_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.biz_source:
            if hasattr(self.biz_source, 'to_alipay_dict'):
                params['biz_source'] = self.biz_source.to_alipay_dict()
            else:
                params['biz_source'] = self.biz_source
        if self.contract_list:
            if isinstance(self.contract_list, list):
                for i in range(0, len(self.contract_list)):
                    element = self.contract_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.contract_list[i] = element.to_alipay_dict()
            if hasattr(self.contract_list, 'to_alipay_dict'):
                params['contract_list'] = self.contract_list.to_alipay_dict()
            else:
                params['contract_list'] = self.contract_list
        if self.start_type:
            if hasattr(self.start_type, 'to_alipay_dict'):
                params['start_type'] = self.start_type.to_alipay_dict()
            else:
                params['start_type'] = self.start_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossContractGeneralCreateModel()
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'biz_source' in d:
            o.biz_source = d['biz_source']
        if 'contract_list' in d:
            o.contract_list = d['contract_list']
        if 'start_type' in d:
            o.start_type = d['start_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossProdContractSignQueryModel(object):

    def __init__(self):
        self._business_id = None
        self._contract_code = None
        self._source_system_id = None
        self._tenant = None

    @property
    def business_id(self):
        return self._business_id

    @business_id.setter
    def business_id(self, value):
        self._business_id = value
    @property
    def contract_code(self):
        return self._contract_code

    @contract_code.setter
    def contract_code(self, value):
        self._contract_code = value
    @property
    def source_system_id(self):
        return self._source_system_id

    @source_system_id.setter
    def source_system_id(self, value):
        self._source_system_id = value
    @property
    def tenant(self):
        return self._tenant

    @tenant.setter
    def tenant(self, value):
        self._tenant = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_id:
            if hasattr(self.business_id, 'to_alipay_dict'):
                params['business_id'] = self.business_id.to_alipay_dict()
            else:
                params['business_id'] = self.business_id
        if self.contract_code:
            if hasattr(self.contract_code, 'to_alipay_dict'):
                params['contract_code'] = self.contract_code.to_alipay_dict()
            else:
                params['contract_code'] = self.contract_code
        if self.source_system_id:
            if hasattr(self.source_system_id, 'to_alipay_dict'):
                params['source_system_id'] = self.source_system_id.to_alipay_dict()
            else:
                params['source_system_id'] = self.source_system_id
        if self.tenant:
            if hasattr(self.tenant, 'to_alipay_dict'):
                params['tenant'] = self.tenant.to_alipay_dict()
            else:
                params['tenant'] = self.tenant
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossProdContractSignQueryModel()
        if 'business_id' in d:
            o.business_id = d['business_id']
        if 'contract_code' in d:
            o.contract_code = d['contract_code']
        if 'source_system_id' in d:
            o.source_system_id = d['source_system_id']
        if 'tenant' in d:
            o.tenant = d['tenant']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundJointaccountFundOrderQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundJointaccountFundOrderQueryResponse, self).__init__()
        self._amount = None
        self._biz_date = None
        self._biz_trans_id = None
        self._error_code = None
        self._error_msg = None
        self._order_title = None
        self._status = None

    @property
    def amount(self):
        return self._amount

    @amount.setter
    def amount(self, value):
        self._amount = value
    @property
    def biz_date(self):
        return self._biz_date

    @biz_date.setter
    def biz_date(self, value):
        self._biz_date = value
    @property
    def biz_trans_id(self):
        return self._biz_trans_id

    @biz_trans_id.setter
    def biz_trans_id(self, value):
        self._biz_trans_id = value
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_msg(self):
        return self._error_msg

    @error_msg.setter
    def error_msg(self, value):
        self._error_msg = value
    @property
    def order_title(self):
        return self._order_title

    @order_title.setter
    def order_title(self, value):
        self._order_title = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundJointaccountFundOrderQueryResponse, self).parse_response_content(response_content)
        if 'amount' in response:
            self.amount = response['amount']
        if 'biz_date' in response:
            self.biz_date = response['biz_date']
        if 'biz_trans_id' in response:
            self.biz_trans_id = response['biz_trans_id']
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'error_msg' in response:
            self.error_msg = response['error_msg']
        if 'order_title' in response:
            self.order_title = response['order_title']
        if 'status' in response:
            self.status = response['status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SCardQueryVO(object):

    def __init__(self):
        self._back_img = None
        self._item_amount = None
        self._item_id = None
        self._name = None
        self._sale_price = None

    @property
    def back_img(self):
        return self._back_img

    @back_img.setter
    def back_img(self, value):
        self._back_img = value
    @property
    def item_amount(self):
        return self._item_amount

    @item_amount.setter
    def item_amount(self, value):
        self._item_amount = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def sale_price(self):
        return self._sale_price

    @sale_price.setter
    def sale_price(self, value):
        self._sale_price = value


    def to_alipay_dict(self):
        params = dict()
        if self.back_img:
            if hasattr(self.back_img, 'to_alipay_dict'):
                params['back_img'] = self.back_img.to_alipay_dict()
            else:
                params['back_img'] = self.back_img
        if self.item_amount:
            if hasattr(self.item_amount, 'to_alipay_dict'):
                params['item_amount'] = self.item_amount.to_alipay_dict()
            else:
                params['item_amount'] = self.item_amount
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.sale_price:
            if hasattr(self.sale_price, 'to_alipay_dict'):
                params['sale_price'] = self.sale_price.to_alipay_dict()
            else:
                params['sale_price'] = self.sale_price
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SCardQueryVO()
        if 'back_img' in d:
            o.back_img = d['back_img']
        if 'item_amount' in d:
            o.item_amount = d['item_amount']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'name' in d:
            o.name = d['name']
        if 'sale_price' in d:
            o.sale_price = d['sale_price']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.BenefitInfo import BenefitInfo


class AlipayMpointprodBenefitDetailGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMpointprodBenefitDetailGetResponse, self).__init__()
        self._benefit_infos = None
        self._code = None
        self._msg = None

    @property
    def benefit_infos(self):
        return self._benefit_infos

    @benefit_infos.setter
    def benefit_infos(self, value):
        if isinstance(value, list):
            self._benefit_infos = list()
            for i in value:
                if isinstance(i, BenefitInfo):
                    self._benefit_infos.append(i)
                else:
                    self._benefit_infos.append(BenefitInfo.from_alipay_dict(i))
    @property
    def code(self):
        return self._code

    @code.setter
    def code(self, value):
        self._code = value
    @property
    def msg(self):
        return self._msg

    @msg.setter
    def msg(self, value):
        self._msg = value

    def parse_response_content(self, response_content):
        response = super(AlipayMpointprodBenefitDetailGetResponse, self).parse_response_content(response_content)
        if 'benefit_infos' in response:
            self.benefit_infos = response['benefit_infos']
        if 'code' in response:
            self.code = response['code']
        if 'msg' in response:
            self.msg = response['msg']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Member import Member


class MybankCreditSupplychainCreditpaySyncnameCreateModel(object):

    def __init__(self):
        self._apply_time = None
        self._channel_tag = None
        self._handle_type = None
        self._promo_end_time = None
        self._promo_start_time = None
        self._promo_type = None
        self._promo_value = None
        self._request_id = None
        self._scene_user_id = None
        self._seller = None

    @property
    def apply_time(self):
        return self._apply_time

    @apply_time.setter
    def apply_time(self, value):
        self._apply_time = value
    @property
    def channel_tag(self):
        return self._channel_tag

    @channel_tag.setter
    def channel_tag(self, value):
        self._channel_tag = value
    @property
    def handle_type(self):
        return self._handle_type

    @handle_type.setter
    def handle_type(self, value):
        self._handle_type = value
    @property
    def promo_end_time(self):
        return self._promo_end_time

    @promo_end_time.setter
    def promo_end_time(self, value):
        self._promo_end_time = value
    @property
    def promo_start_time(self):
        return self._promo_start_time

    @promo_start_time.setter
    def promo_start_time(self, value):
        self._promo_start_time = value
    @property
    def promo_type(self):
        return self._promo_type

    @promo_type.setter
    def promo_type(self, value):
        self._promo_type = value
    @property
    def promo_value(self):
        return self._promo_value

    @promo_value.setter
    def promo_value(self, value):
        self._promo_value = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def scene_user_id(self):
        return self._scene_user_id

    @scene_user_id.setter
    def scene_user_id(self, value):
        self._scene_user_id = value
    @property
    def seller(self):
        return self._seller

    @seller.setter
    def seller(self, value):
        if isinstance(value, Member):
            self._seller = value
        else:
            self._seller = Member.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.apply_time:
            if hasattr(self.apply_time, 'to_alipay_dict'):
                params['apply_time'] = self.apply_time.to_alipay_dict()
            else:
                params['apply_time'] = self.apply_time
        if self.channel_tag:
            if hasattr(self.channel_tag, 'to_alipay_dict'):
                params['channel_tag'] = self.channel_tag.to_alipay_dict()
            else:
                params['channel_tag'] = self.channel_tag
        if self.handle_type:
            if hasattr(self.handle_type, 'to_alipay_dict'):
                params['handle_type'] = self.handle_type.to_alipay_dict()
            else:
                params['handle_type'] = self.handle_type
        if self.promo_end_time:
            if hasattr(self.promo_end_time, 'to_alipay_dict'):
                params['promo_end_time'] = self.promo_end_time.to_alipay_dict()
            else:
                params['promo_end_time'] = self.promo_end_time
        if self.promo_start_time:
            if hasattr(self.promo_start_time, 'to_alipay_dict'):
                params['promo_start_time'] = self.promo_start_time.to_alipay_dict()
            else:
                params['promo_start_time'] = self.promo_start_time
        if self.promo_type:
            if hasattr(self.promo_type, 'to_alipay_dict'):
                params['promo_type'] = self.promo_type.to_alipay_dict()
            else:
                params['promo_type'] = self.promo_type
        if self.promo_value:
            if hasattr(self.promo_value, 'to_alipay_dict'):
                params['promo_value'] = self.promo_value.to_alipay_dict()
            else:
                params['promo_value'] = self.promo_value
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.scene_user_id:
            if hasattr(self.scene_user_id, 'to_alipay_dict'):
                params['scene_user_id'] = self.scene_user_id.to_alipay_dict()
            else:
                params['scene_user_id'] = self.scene_user_id
        if self.seller:
            if hasattr(self.seller, 'to_alipay_dict'):
                params['seller'] = self.seller.to_alipay_dict()
            else:
                params['seller'] = self.seller
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditSupplychainCreditpaySyncnameCreateModel()
        if 'apply_time' in d:
            o.apply_time = d['apply_time']
        if 'channel_tag' in d:
            o.channel_tag = d['channel_tag']
        if 'handle_type' in d:
            o.handle_type = d['handle_type']
        if 'promo_end_time' in d:
            o.promo_end_time = d['promo_end_time']
        if 'promo_start_time' in d:
            o.promo_start_time = d['promo_start_time']
        if 'promo_type' in d:
            o.promo_type = d['promo_type']
        if 'promo_value' in d:
            o.promo_value = d['promo_value']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'scene_user_id' in d:
            o.scene_user_id = d['scene_user_id']
        if 'seller' in d:
            o.seller = d['seller']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMarketingToolPrizesendAuthModel(object):

    def __init__(self):
        self._prize_id = None
        self._req_id = None
        self._user_id = None

    @property
    def prize_id(self):
        return self._prize_id

    @prize_id.setter
    def prize_id(self, value):
        self._prize_id = value
    @property
    def req_id(self):
        return self._req_id

    @req_id.setter
    def req_id(self, value):
        self._req_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.prize_id:
            if hasattr(self.prize_id, 'to_alipay_dict'):
                params['prize_id'] = self.prize_id.to_alipay_dict()
            else:
                params['prize_id'] = self.prize_id
        if self.req_id:
            if hasattr(self.req_id, 'to_alipay_dict'):
                params['req_id'] = self.req_id.to_alipay_dict()
            else:
                params['req_id'] = self.req_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingToolPrizesendAuthModel()
        if 'prize_id' in d:
            o.prize_id = d['prize_id']
        if 'req_id' in d:
            o.req_id = d['req_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataBillTransferQueryModel(object):

    def __init__(self):
        self._end_time = None
        self._page_no = None
        self._page_size = None
        self._start_time = None
        self._type = None

    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataBillTransferQueryModel()
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DiscountModel(object):

    def __init__(self):
        self._term_discount = None
        self._term_no = None

    @property
    def term_discount(self):
        return self._term_discount

    @term_discount.setter
    def term_discount(self, value):
        self._term_discount = value
    @property
    def term_no(self):
        return self._term_no

    @term_no.setter
    def term_no(self, value):
        self._term_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.term_discount:
            if hasattr(self.term_discount, 'to_alipay_dict'):
                params['term_discount'] = self.term_discount.to_alipay_dict()
            else:
                params['term_discount'] = self.term_discount
        if self.term_no:
            if hasattr(self.term_no, 'to_alipay_dict'):
                params['term_no'] = self.term_no.to_alipay_dict()
            else:
                params['term_no'] = self.term_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DiscountModel()
        if 'term_discount' in d:
            o.term_discount = d['term_discount']
        if 'term_no' in d:
            o.term_no = d['term_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.LoanPayAssetResult import LoanPayAssetResult
from alipay.aop.api.domain.Refuse import Refuse


class MybankCreditLoantradeLoanpayAssetConsultResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditLoantradeLoanpayAssetConsultResponse, self).__init__()
        self._asset_result = None
        self._refuse_msg = None
        self._success = None

    @property
    def asset_result(self):
        return self._asset_result

    @asset_result.setter
    def asset_result(self, value):
        if isinstance(value, LoanPayAssetResult):
            self._asset_result = value
        else:
            self._asset_result = LoanPayAssetResult.from_alipay_dict(value)
    @property
    def refuse_msg(self):
        return self._refuse_msg

    @refuse_msg.setter
    def refuse_msg(self, value):
        if isinstance(value, Refuse):
            self._refuse_msg = value
        else:
            self._refuse_msg = Refuse.from_alipay_dict(value)
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditLoantradeLoanpayAssetConsultResponse, self).parse_response_content(response_content)
        if 'asset_result' in response:
            self.asset_result = response['asset_result']
        if 'refuse_msg' in response:
            self.refuse_msg = response['refuse_msg']
        if 'success' in response:
            self.success = response['success']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SealPosition(object):

    def __init__(self):
        self._keyword = None
        self._page_no = None
        self._type = None
        self._x = None
        self._y = None

    @property
    def keyword(self):
        return self._keyword

    @keyword.setter
    def keyword(self, value):
        self._keyword = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value
    @property
    def x(self):
        return self._x

    @x.setter
    def x(self, value):
        self._x = value
    @property
    def y(self):
        return self._y

    @y.setter
    def y(self, value):
        self._y = value


    def to_alipay_dict(self):
        params = dict()
        if self.keyword:
            if hasattr(self.keyword, 'to_alipay_dict'):
                params['keyword'] = self.keyword.to_alipay_dict()
            else:
                params['keyword'] = self.keyword
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        if self.x:
            if hasattr(self.x, 'to_alipay_dict'):
                params['x'] = self.x.to_alipay_dict()
            else:
                params['x'] = self.x
        if self.y:
            if hasattr(self.y, 'to_alipay_dict'):
                params['y'] = self.y.to_alipay_dict()
            else:
                params['y'] = self.y
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SealPosition()
        if 'keyword' in d:
            o.keyword = d['keyword']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'type' in d:
            o.type = d['type']
        if 'x' in d:
            o.x = d['x']
        if 'y' in d:
            o.y = d['y']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SceneContent import SceneContent
from alipay.aop.api.domain.SceneDetail import SceneDetail


class AlipaySocialBaseSceneContentQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipaySocialBaseSceneContentQueryResponse, self).__init__()
        self._scene_content = None
        self._scene_detail = None
        self._scheme = None

    @property
    def scene_content(self):
        return self._scene_content

    @scene_content.setter
    def scene_content(self, value):
        if isinstance(value, list):
            self._scene_content = list()
            for i in value:
                if isinstance(i, SceneContent):
                    self._scene_content.append(i)
                else:
                    self._scene_content.append(SceneContent.from_alipay_dict(i))
    @property
    def scene_detail(self):
        return self._scene_detail

    @scene_detail.setter
    def scene_detail(self, value):
        if isinstance(value, SceneDetail):
            self._scene_detail = value
        else:
            self._scene_detail = SceneDetail.from_alipay_dict(value)
    @property
    def scheme(self):
        return self._scheme

    @scheme.setter
    def scheme(self, value):
        self._scheme = value

    def parse_response_content(self, response_content):
        response = super(AlipaySocialBaseSceneContentQueryResponse, self).parse_response_content(response_content)
        if 'scene_content' in response:
            self.scene_content = response['scene_content']
        if 'scene_detail' in response:
            self.scene_detail = response['scene_detail']
        if 'scheme' in response:
            self.scheme = response['scheme']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AoiUser import AoiUser


class AlipayMerchantAuthCreateModel(object):

    def __init__(self):
        self._channel_code = None
        self._operator_id = None
        self._role = None
        self._scene_code = None
        self._user_list = None

    @property
    def channel_code(self):
        return self._channel_code

    @channel_code.setter
    def channel_code(self, value):
        self._channel_code = value
    @property
    def operator_id(self):
        return self._operator_id

    @operator_id.setter
    def operator_id(self, value):
        self._operator_id = value
    @property
    def role(self):
        return self._role

    @role.setter
    def role(self, value):
        self._role = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def user_list(self):
        return self._user_list

    @user_list.setter
    def user_list(self, value):
        if isinstance(value, AoiUser):
            self._user_list = value
        else:
            self._user_list = AoiUser.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.channel_code:
            if hasattr(self.channel_code, 'to_alipay_dict'):
                params['channel_code'] = self.channel_code.to_alipay_dict()
            else:
                params['channel_code'] = self.channel_code
        if self.operator_id:
            if hasattr(self.operator_id, 'to_alipay_dict'):
                params['operator_id'] = self.operator_id.to_alipay_dict()
            else:
                params['operator_id'] = self.operator_id
        if self.role:
            if hasattr(self.role, 'to_alipay_dict'):
                params['role'] = self.role.to_alipay_dict()
            else:
                params['role'] = self.role
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.user_list:
            if hasattr(self.user_list, 'to_alipay_dict'):
                params['user_list'] = self.user_list.to_alipay_dict()
            else:
                params['user_list'] = self.user_list
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMerchantAuthCreateModel()
        if 'channel_code' in d:
            o.channel_code = d['channel_code']
        if 'operator_id' in d:
            o.operator_id = d['operator_id']
        if 'role' in d:
            o.role = d['role']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'user_list' in d:
            o.user_list = d['user_list']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AccountingLogVO(object):

    def __init__(self):
        self._account_no = None
        self._account_type = None
        self._action = None
        self._balance = None
        self._log_id = None
        self._order_no = None
        self._other_account = None
        self._out_request_no = None
        self._trans_amount = None
        self._trans_dt = None
        self._trans_memo = None

    @property
    def account_no(self):
        return self._account_no

    @account_no.setter
    def account_no(self, value):
        self._account_no = value
    @property
    def account_type(self):
        return self._account_type

    @account_type.setter
    def account_type(self, value):
        self._account_type = value
    @property
    def action(self):
        return self._action

    @action.setter
    def action(self, value):
        self._action = value
    @property
    def balance(self):
        return self._balance

    @balance.setter
    def balance(self, value):
        self._balance = value
    @property
    def log_id(self):
        return self._log_id

    @log_id.setter
    def log_id(self, value):
        self._log_id = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def other_account(self):
        return self._other_account

    @other_account.setter
    def other_account(self, value):
        self._other_account = value
    @property
    def out_request_no(self):
        return self._out_request_no

    @out_request_no.setter
    def out_request_no(self, value):
        self._out_request_no = value
    @property
    def trans_amount(self):
        return self._trans_amount

    @trans_amount.setter
    def trans_amount(self, value):
        self._trans_amount = value
    @property
    def trans_dt(self):
        return self._trans_dt

    @trans_dt.setter
    def trans_dt(self, value):
        self._trans_dt = value
    @property
    def trans_memo(self):
        return self._trans_memo

    @trans_memo.setter
    def trans_memo(self, value):
        self._trans_memo = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_no:
            if hasattr(self.account_no, 'to_alipay_dict'):
                params['account_no'] = self.account_no.to_alipay_dict()
            else:
                params['account_no'] = self.account_no
        if self.account_type:
            if hasattr(self.account_type, 'to_alipay_dict'):
                params['account_type'] = self.account_type.to_alipay_dict()
            else:
                params['account_type'] = self.account_type
        if self.action:
            if hasattr(self.action, 'to_alipay_dict'):
                params['action'] = self.action.to_alipay_dict()
            else:
                params['action'] = self.action
        if self.balance:
            if hasattr(self.balance, 'to_alipay_dict'):
                params['balance'] = self.balance.to_alipay_dict()
            else:
                params['balance'] = self.balance
        if self.log_id:
            if hasattr(self.log_id, 'to_alipay_dict'):
                params['log_id'] = self.log_id.to_alipay_dict()
            else:
                params['log_id'] = self.log_id
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.other_account:
            if hasattr(self.other_account, 'to_alipay_dict'):
                params['other_account'] = self.other_account.to_alipay_dict()
            else:
                params['other_account'] = self.other_account
        if self.out_request_no:
            if hasattr(self.out_request_no, 'to_alipay_dict'):
                params['out_request_no'] = self.out_request_no.to_alipay_dict()
            else:
                params['out_request_no'] = self.out_request_no
        if self.trans_amount:
            if hasattr(self.trans_amount, 'to_alipay_dict'):
                params['trans_amount'] = self.trans_amount.to_alipay_dict()
            else:
                params['trans_amount'] = self.trans_amount
        if self.trans_dt:
            if hasattr(self.trans_dt, 'to_alipay_dict'):
                params['trans_dt'] = self.trans_dt.to_alipay_dict()
            else:
                params['trans_dt'] = self.trans_dt
        if self.trans_memo:
            if hasattr(self.trans_memo, 'to_alipay_dict'):
                params['trans_memo'] = self.trans_memo.to_alipay_dict()
            else:
                params['trans_memo'] = self.trans_memo
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AccountingLogVO()
        if 'account_no' in d:
            o.account_no = d['account_no']
        if 'account_type' in d:
            o.account_type = d['account_type']
        if 'action' in d:
            o.action = d['action']
        if 'balance' in d:
            o.balance = d['balance']
        if 'log_id' in d:
            o.log_id = d['log_id']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'other_account' in d:
            o.other_account = d['other_account']
        if 'out_request_no' in d:
            o.out_request_no = d['out_request_no']
        if 'trans_amount' in d:
            o.trans_amount = d['trans_amount']
        if 'trans_dt' in d:
            o.trans_dt = d['trans_dt']
        if 'trans_memo' in d:
            o.trans_memo = d['trans_memo']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPayAppTradeArrearSyncModel(object):

    def __init__(self):
        self._biz_scene = None
        self._goods_digest = None
        self._merchant_name = None
        self._trade_no = None

    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def goods_digest(self):
        return self._goods_digest

    @goods_digest.setter
    def goods_digest(self, value):
        self._goods_digest = value
    @property
    def merchant_name(self):
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, value):
        self._merchant_name = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.goods_digest:
            if hasattr(self.goods_digest, 'to_alipay_dict'):
                params['goods_digest'] = self.goods_digest.to_alipay_dict()
            else:
                params['goods_digest'] = self.goods_digest
        if self.merchant_name:
            if hasattr(self.merchant_name, 'to_alipay_dict'):
                params['merchant_name'] = self.merchant_name.to_alipay_dict()
            else:
                params['merchant_name'] = self.merchant_name
        if self.trade_no:
            if hasattr(self.trade_no, 'to_alipay_dict'):
                params['trade_no'] = self.trade_no.to_alipay_dict()
            else:
                params['trade_no'] = self.trade_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPayAppTradeArrearSyncModel()
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'goods_digest' in d:
            o.goods_digest = d['goods_digest']
        if 'merchant_name' in d:
            o.merchant_name = d['merchant_name']
        if 'trade_no' in d:
            o.trade_no = d['trade_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KbadvertVoucherManual import KbadvertVoucherManual


class KbAdvertSubjectVoucherResponse(object):

    def __init__(self):
        self._brand_name = None
        self._city_ids = None
        self._cover = None
        self._daily_inventory = None
        self._gmt_end = None
        self._gmt_start = None
        self._logo = None
        self._manuals = None
        self._merchant_name = None
        self._partner_id = None
        self._purchase_mode = None
        self._shop_ids = None
        self._threshold_amount = None
        self._total_inventory = None
        self._voucher_id = None
        self._voucher_name = None
        self._voucher_org_value = None
        self._voucher_type = None
        self._voucher_value = None

    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def city_ids(self):
        return self._city_ids

    @city_ids.setter
    def city_ids(self, value):
        if isinstance(value, list):
            self._city_ids = list()
            for i in value:
                self._city_ids.append(i)
    @property
    def cover(self):
        return self._cover

    @cover.setter
    def cover(self, value):
        self._cover = value
    @property
    def daily_inventory(self):
        return self._daily_inventory

    @daily_inventory.setter
    def daily_inventory(self, value):
        self._daily_inventory = value
    @property
    def gmt_end(self):
        return self._gmt_end

    @gmt_end.setter
    def gmt_end(self, value):
        self._gmt_end = value
    @property
    def gmt_start(self):
        return self._gmt_start

    @gmt_start.setter
    def gmt_start(self, value):
        self._gmt_start = value
    @property
    def logo(self):
        return self._logo

    @logo.setter
    def logo(self, value):
        self._logo = value
    @property
    def manuals(self):
        return self._manuals

    @manuals.setter
    def manuals(self, value):
        if isinstance(value, list):
            self._manuals = list()
            for i in value:
                if isinstance(i, KbadvertVoucherManual):
                    self._manuals.append(i)
                else:
                    self._manuals.append(KbadvertVoucherManual.from_alipay_dict(i))
    @property
    def merchant_name(self):
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, value):
        self._merchant_name = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def purchase_mode(self):
        return self._purchase_mode

    @purchase_mode.setter
    def purchase_mode(self, value):
        self._purchase_mode = value
    @property
    def shop_ids(self):
        return self._shop_ids

    @shop_ids.setter
    def shop_ids(self, value):
        if isinstance(value, list):
            self._shop_ids = list()
            for i in value:
                self._shop_ids.append(i)
    @property
    def threshold_amount(self):
        return self._threshold_amount

    @threshold_amount.setter
    def threshold_amount(self, value):
        self._threshold_amount = value
    @property
    def total_inventory(self):
        return self._total_inventory

    @total_inventory.setter
    def total_inventory(self, value):
        self._total_inventory = value
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value
    @property
    def voucher_name(self):
        return self._voucher_name

    @voucher_name.setter
    def voucher_name(self, value):
        self._voucher_name = value
    @property
    def voucher_org_value(self):
        return self._voucher_org_value

    @voucher_org_value.setter
    def voucher_org_value(self, value):
        self._voucher_org_value = value
    @property
    def voucher_type(self):
        return self._voucher_type

    @voucher_type.setter
    def voucher_type(self, value):
        self._voucher_type = value
    @property
    def voucher_value(self):
        return self._voucher_value

    @voucher_value.setter
    def voucher_value(self, value):
        self._voucher_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.city_ids:
            if isinstance(self.city_ids, list):
                for i in range(0, len(self.city_ids)):
                    element = self.city_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.city_ids[i] = element.to_alipay_dict()
            if hasattr(self.city_ids, 'to_alipay_dict'):
                params['city_ids'] = self.city_ids.to_alipay_dict()
            else:
                params['city_ids'] = self.city_ids
        if self.cover:
            if hasattr(self.cover, 'to_alipay_dict'):
                params['cover'] = self.cover.to_alipay_dict()
            else:
                params['cover'] = self.cover
        if self.daily_inventory:
            if hasattr(self.daily_inventory, 'to_alipay_dict'):
                params['daily_inventory'] = self.daily_inventory.to_alipay_dict()
            else:
                params['daily_inventory'] = self.daily_inventory
        if self.gmt_end:
            if hasattr(self.gmt_end, 'to_alipay_dict'):
                params['gmt_end'] = self.gmt_end.to_alipay_dict()
            else:
                params['gmt_end'] = self.gmt_end
        if self.gmt_start:
            if hasattr(self.gmt_start, 'to_alipay_dict'):
                params['gmt_start'] = self.gmt_start.to_alipay_dict()
            else:
                params['gmt_start'] = self.gmt_start
        if self.logo:
            if hasattr(self.logo, 'to_alipay_dict'):
                params['logo'] = self.logo.to_alipay_dict()
            else:
                params['logo'] = self.logo
        if self.manuals:
            if isinstance(self.manuals, list):
                for i in range(0, len(self.manuals)):
                    element = self.manuals[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.manuals[i] = element.to_alipay_dict()
            if hasattr(self.manuals, 'to_alipay_dict'):
                params['manuals'] = self.manuals.to_alipay_dict()
            else:
                params['manuals'] = self.manuals
        if self.merchant_name:
            if hasattr(self.merchant_name, 'to_alipay_dict'):
                params['merchant_name'] = self.merchant_name.to_alipay_dict()
            else:
                params['merchant_name'] = self.merchant_name
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.purchase_mode:
            if hasattr(self.purchase_mode, 'to_alipay_dict'):
                params['purchase_mode'] = self.purchase_mode.to_alipay_dict()
            else:
                params['purchase_mode'] = self.purchase_mode
        if self.shop_ids:
            if isinstance(self.shop_ids, list):
                for i in range(0, len(self.shop_ids)):
                    element = self.shop_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.shop_ids[i] = element.to_alipay_dict()
            if hasattr(self.shop_ids, 'to_alipay_dict'):
                params['shop_ids'] = self.shop_ids.to_alipay_dict()
            else:
                params['shop_ids'] = self.shop_ids
        if self.threshold_amount:
            if hasattr(self.threshold_amount, 'to_alipay_dict'):
                params['threshold_amount'] = self.threshold_amount.to_alipay_dict()
            else:
                params['threshold_amount'] = self.threshold_amount
        if self.total_inventory:
            if hasattr(self.total_inventory, 'to_alipay_dict'):
                params['total_inventory'] = self.total_inventory.to_alipay_dict()
            else:
                params['total_inventory'] = self.total_inventory
        if self.voucher_id:
            if hasattr(self.voucher_id, 'to_alipay_dict'):
                params['voucher_id'] = self.voucher_id.to_alipay_dict()
            else:
                params['voucher_id'] = self.voucher_id
        if self.voucher_name:
            if hasattr(self.voucher_name, 'to_alipay_dict'):
                params['voucher_name'] = self.voucher_name.to_alipay_dict()
            else:
                params['voucher_name'] = self.voucher_name
        if self.voucher_org_value:
            if hasattr(self.voucher_org_value, 'to_alipay_dict'):
                params['voucher_org_value'] = self.voucher_org_value.to_alipay_dict()
            else:
                params['voucher_org_value'] = self.voucher_org_value
        if self.voucher_type:
            if hasattr(self.voucher_type, 'to_alipay_dict'):
                params['voucher_type'] = self.voucher_type.to_alipay_dict()
            else:
                params['voucher_type'] = self.voucher_type
        if self.voucher_value:
            if hasattr(self.voucher_value, 'to_alipay_dict'):
                params['voucher_value'] = self.voucher_value.to_alipay_dict()
            else:
                params['voucher_value'] = self.voucher_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbAdvertSubjectVoucherResponse()
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'city_ids' in d:
            o.city_ids = d['city_ids']
        if 'cover' in d:
            o.cover = d['cover']
        if 'daily_inventory' in d:
            o.daily_inventory = d['daily_inventory']
        if 'gmt_end' in d:
            o.gmt_end = d['gmt_end']
        if 'gmt_start' in d:
            o.gmt_start = d['gmt_start']
        if 'logo' in d:
            o.logo = d['logo']
        if 'manuals' in d:
            o.manuals = d['manuals']
        if 'merchant_name' in d:
            o.merchant_name = d['merchant_name']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'purchase_mode' in d:
            o.purchase_mode = d['purchase_mode']
        if 'shop_ids' in d:
            o.shop_ids = d['shop_ids']
        if 'threshold_amount' in d:
            o.threshold_amount = d['threshold_amount']
        if 'total_inventory' in d:
            o.total_inventory = d['total_inventory']
        if 'voucher_id' in d:
            o.voucher_id = d['voucher_id']
        if 'voucher_name' in d:
            o.voucher_name = d['voucher_name']
        if 'voucher_org_value' in d:
            o.voucher_org_value = d['voucher_org_value']
        if 'voucher_type' in d:
            o.voucher_type = d['voucher_type']
        if 'voucher_value' in d:
            o.voucher_value = d['voucher_value']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.TemplateActionInfoDTO import TemplateActionInfoDTO
from alipay.aop.api.domain.TemplateCardLevelConfDTO import TemplateCardLevelConfDTO
from alipay.aop.api.domain.TemplateColumnInfoDTO import TemplateColumnInfoDTO
from alipay.aop.api.domain.TemplateFieldRuleDTO import TemplateFieldRuleDTO
from alipay.aop.api.domain.TemplateMdcodeNotifyConfDTO import TemplateMdcodeNotifyConfDTO
from alipay.aop.api.domain.TemplateOpenCardConfDTO import TemplateOpenCardConfDTO
from alipay.aop.api.domain.PaidOuterCardTemplateConfDTO import PaidOuterCardTemplateConfDTO
from alipay.aop.api.domain.PubChannelDTO import PubChannelDTO
from alipay.aop.api.domain.TemplateBenefitInfoDTO import TemplateBenefitInfoDTO
from alipay.aop.api.domain.TemplateStyleInfoDTO import TemplateStyleInfoDTO


class AlipayMarketingCardTemplateQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingCardTemplateQueryResponse, self).__init__()
        self._biz_no_prefix = None
        self._biz_no_suffix_len = None
        self._card_action_list = None
        self._card_level_confs = None
        self._card_spec_tag = None
        self._card_type = None
        self._column_info_list = None
        self._field_rule_list = None
        self._mdcode_notify_conf = None
        self._open_card_conf = None
        self._paid_outer_card_conf = None
        self._pub_channels = None
        self._service_label_list = None
        self._shop_ids = None
        self._template_benefit_info = None
        self._template_style_info = None

    @property
    def biz_no_prefix(self):
        return self._biz_no_prefix

    @biz_no_prefix.setter
    def biz_no_prefix(self, value):
        self._biz_no_prefix = value
    @property
    def biz_no_suffix_len(self):
        return self._biz_no_suffix_len

    @biz_no_suffix_len.setter
    def biz_no_suffix_len(self, value):
        self._biz_no_suffix_len = value
    @property
    def card_action_list(self):
        return self._card_action_list

    @card_action_list.setter
    def card_action_list(self, value):
        if isinstance(value, list):
            self._card_action_list = list()
            for i in value:
                if isinstance(i, TemplateActionInfoDTO):
                    self._card_action_list.append(i)
                else:
                    self._card_action_list.append(TemplateActionInfoDTO.from_alipay_dict(i))
    @property
    def card_level_confs(self):
        return self._card_level_confs

    @card_level_confs.setter
    def card_level_confs(self, value):
        if isinstance(value, list):
            self._card_level_confs = list()
            for i in value:
                if isinstance(i, TemplateCardLevelConfDTO):
                    self._card_level_confs.append(i)
                else:
                    self._card_level_confs.append(TemplateCardLevelConfDTO.from_alipay_dict(i))
    @property
    def card_spec_tag(self):
        return self._card_spec_tag

    @card_spec_tag.setter
    def card_spec_tag(self, value):
        self._card_spec_tag = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def column_info_list(self):
        return self._column_info_list

    @column_info_list.setter
    def column_info_list(self, value):
        if isinstance(value, list):
            self._column_info_list = list()
            for i in value:
                if isinstance(i, TemplateColumnInfoDTO):
                    self._column_info_list.append(i)
                else:
                    self._column_info_list.append(TemplateColumnInfoDTO.from_alipay_dict(i))
    @property
    def field_rule_list(self):
        return self._field_rule_list

    @field_rule_list.setter
    def field_rule_list(self, value):
        if isinstance(value, list):
            self._field_rule_list = list()
            for i in value:
                if isinstance(i, TemplateFieldRuleDTO):
                    self._field_rule_list.append(i)
                else:
                    self._field_rule_list.append(TemplateFieldRuleDTO.from_alipay_dict(i))
    @property
    def mdcode_notify_conf(self):
        return self._mdcode_notify_conf

    @mdcode_notify_conf.setter
    def mdcode_notify_conf(self, value):
        if isinstance(value, TemplateMdcodeNotifyConfDTO):
            self._mdcode_notify_conf = value
        else:
            self._mdcode_notify_conf = TemplateMdcodeNotifyConfDTO.from_alipay_dict(value)
    @property
    def open_card_conf(self):
        return self._open_card_conf

    @open_card_conf.setter
    def open_card_conf(self, value):
        if isinstance(value, TemplateOpenCardConfDTO):
            self._open_card_conf = value
        else:
            self._open_card_conf = TemplateOpenCardConfDTO.from_alipay_dict(value)
    @property
    def paid_outer_card_conf(self):
        return self._paid_outer_card_conf

    @paid_outer_card_conf.setter
    def paid_outer_card_conf(self, value):
        if isinstance(value, PaidOuterCardTemplateConfDTO):
            self._paid_outer_card_conf = value
        else:
            self._paid_outer_card_conf = PaidOuterCardTemplateConfDTO.from_alipay_dict(value)
    @property
    def pub_channels(self):
        return self._pub_channels

    @pub_channels.setter
    def pub_channels(self, value):
        if isinstance(value, list):
            self._pub_channels = list()
            for i in value:
                if isinstance(i, PubChannelDTO):
                    self._pub_channels.append(i)
                else:
                    self._pub_channels.append(PubChannelDTO.from_alipay_dict(i))
    @property
    def service_label_list(self):
        return self._service_label_list

    @service_label_list.setter
    def service_label_list(self, value):
        if isinstance(value, list):
            self._service_label_list = list()
            for i in value:
                self._service_label_list.append(i)
    @property
    def shop_ids(self):
        return self._shop_ids

    @shop_ids.setter
    def shop_ids(self, value):
        if isinstance(value, list):
            self._shop_ids = list()
            for i in value:
                self._shop_ids.append(i)
    @property
    def template_benefit_info(self):
        return self._template_benefit_info

    @template_benefit_info.setter
    def template_benefit_info(self, value):
        if isinstance(value, list):
            self._template_benefit_info = list()
            for i in value:
                if isinstance(i, TemplateBenefitInfoDTO):
                    self._template_benefit_info.append(i)
                else:
                    self._template_benefit_info.append(TemplateBenefitInfoDTO.from_alipay_dict(i))
    @property
    def template_style_info(self):
        return self._template_style_info

    @template_style_info.setter
    def template_style_info(self, value):
        if isinstance(value, TemplateStyleInfoDTO):
            self._template_style_info = value
        else:
            self._template_style_info = TemplateStyleInfoDTO.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingCardTemplateQueryResponse, self).parse_response_content(response_content)
        if 'biz_no_prefix' in response:
            self.biz_no_prefix = response['biz_no_prefix']
        if 'biz_no_suffix_len' in response:
            self.biz_no_suffix_len = response['biz_no_suffix_len']
        if 'card_action_list' in response:
            self.card_action_list = response['card_action_list']
        if 'card_level_confs' in response:
            self.card_level_confs = response['card_level_confs']
        if 'card_spec_tag' in response:
            self.card_spec_tag = response['card_spec_tag']
        if 'card_type' in response:
            self.card_type = response['card_type']
        if 'column_info_list' in response:
            self.column_info_list = response['column_info_list']
        if 'field_rule_list' in response:
            self.field_rule_list = response['field_rule_list']
        if 'mdcode_notify_conf' in response:
            self.mdcode_notify_conf = response['mdcode_notify_conf']
        if 'open_card_conf' in response:
            self.open_card_conf = response['open_card_conf']
        if 'paid_outer_card_conf' in response:
            self.paid_outer_card_conf = response['paid_outer_card_conf']
        if 'pub_channels' in response:
            self.pub_channels = response['pub_channels']
        if 'service_label_list' in response:
            self.service_label_list = response['service_label_list']
        if 'shop_ids' in response:
            self.shop_ids = response['shop_ids']
        if 'template_benefit_info' in response:
            self.template_benefit_info = response['template_benefit_info']
        if 'template_style_info' in response:
            self.template_style_info = response['template_style_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCreditRiskEvaluateQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditRiskEvaluateQueryResponse, self).__init__()
        self._accessible = None
        self._biz_no = None
        self._limit_level = None
        self._risk_code = None
        self._score_level = None

    @property
    def accessible(self):
        return self._accessible

    @accessible.setter
    def accessible(self, value):
        self._accessible = value
    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def limit_level(self):
        return self._limit_level

    @limit_level.setter
    def limit_level(self, value):
        self._limit_level = value
    @property
    def risk_code(self):
        return self._risk_code

    @risk_code.setter
    def risk_code(self, value):
        self._risk_code = value
    @property
    def score_level(self):
        return self._score_level

    @score_level.setter
    def score_level(self, value):
        self._score_level = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditRiskEvaluateQueryResponse, self).parse_response_content(response_content)
        if 'accessible' in response:
            self.accessible = response['accessible']
        if 'biz_no' in response:
            self.biz_no = response['biz_no']
        if 'limit_level' in response:
            self.limit_level = response['limit_level']
        if 'risk_code' in response:
            self.risk_code = response['risk_code']
        if 'score_level' in response:
            self.score_level = response['score_level']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Money import Money
from alipay.aop.api.domain.Money import Money


class AlipayOverseasTransferConfirmModel(object):

    def __init__(self):
        self._additional_transfer_details = None
        self._beneficiary_agent_id = None
        self._beneficiary_receipt_method = None
        self._biz_scene_type = None
        self._instructed_amount_type = None
        self._pass_through_info = None
        self._payer_agent_id = None
        self._payer_payment_method = None
        self._transfer_from_amount = None
        self._transfer_notify_url = None
        self._transfer_quote = None
        self._transfer_request_id = None
        self._transfer_to_amount = None

    @property
    def additional_transfer_details(self):
        return self._additional_transfer_details

    @additional_transfer_details.setter
    def additional_transfer_details(self, value):
        self._additional_transfer_details = value
    @property
    def beneficiary_agent_id(self):
        return self._beneficiary_agent_id

    @beneficiary_agent_id.setter
    def beneficiary_agent_id(self, value):
        self._beneficiary_agent_id = value
    @property
    def beneficiary_receipt_method(self):
        return self._beneficiary_receipt_method

    @beneficiary_receipt_method.setter
    def beneficiary_receipt_method(self, value):
        self._beneficiary_receipt_method = value
    @property
    def biz_scene_type(self):
        return self._biz_scene_type

    @biz_scene_type.setter
    def biz_scene_type(self, value):
        self._biz_scene_type = value
    @property
    def instructed_amount_type(self):
        return self._instructed_amount_type

    @instructed_amount_type.setter
    def instructed_amount_type(self, value):
        self._instructed_amount_type = value
    @property
    def pass_through_info(self):
        return self._pass_through_info

    @pass_through_info.setter
    def pass_through_info(self, value):
        self._pass_through_info = value
    @property
    def payer_agent_id(self):
        return self._payer_agent_id

    @payer_agent_id.setter
    def payer_agent_id(self, value):
        self._payer_agent_id = value
    @property
    def payer_payment_method(self):
        return self._payer_payment_method

    @payer_payment_method.setter
    def payer_payment_method(self, value):
        self._payer_payment_method = value
    @property
    def transfer_from_amount(self):
        return self._transfer_from_amount

    @transfer_from_amount.setter
    def transfer_from_amount(self, value):
        if isinstance(value, Money):
            self._transfer_from_amount = value
        else:
            self._transfer_from_amount = Money.from_alipay_dict(value)
    @property
    def transfer_notify_url(self):
        return self._transfer_notify_url

    @transfer_notify_url.setter
    def transfer_notify_url(self, value):
        self._transfer_notify_url = value
    @property
    def transfer_quote(self):
        return self._transfer_quote

    @transfer_quote.setter
    def transfer_quote(self, value):
        self._transfer_quote = value
    @property
    def transfer_request_id(self):
        return self._transfer_request_id

    @transfer_request_id.setter
    def transfer_request_id(self, value):
        self._transfer_request_id = value
    @property
    def transfer_to_amount(self):
        return self._transfer_to_amount

    @transfer_to_amount.setter
    def transfer_to_amount(self, value):
        if isinstance(value, Money):
            self._transfer_to_amount = value
        else:
            self._transfer_to_amount = Money.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.additional_transfer_details:
            if hasattr(self.additional_transfer_details, 'to_alipay_dict'):
                params['additional_transfer_details'] = self.additional_transfer_details.to_alipay_dict()
            else:
                params['additional_transfer_details'] = self.additional_transfer_details
        if self.beneficiary_agent_id:
            if hasattr(self.beneficiary_agent_id, 'to_alipay_dict'):
                params['beneficiary_agent_id'] = self.beneficiary_agent_id.to_alipay_dict()
            else:
                params['beneficiary_agent_id'] = self.beneficiary_agent_id
        if self.beneficiary_receipt_method:
            if hasattr(self.beneficiary_receipt_method, 'to_alipay_dict'):
                params['beneficiary_receipt_method'] = self.beneficiary_receipt_method.to_alipay_dict()
            else:
                params['beneficiary_receipt_method'] = self.beneficiary_receipt_method
        if self.biz_scene_type:
            if hasattr(self.biz_scene_type, 'to_alipay_dict'):
                params['biz_scene_type'] = self.biz_scene_type.to_alipay_dict()
            else:
                params['biz_scene_type'] = self.biz_scene_type
        if self.instructed_amount_type:
            if hasattr(self.instructed_amount_type, 'to_alipay_dict'):
                params['instructed_amount_type'] = self.instructed_amount_type.to_alipay_dict()
            else:
                params['instructed_amount_type'] = self.instructed_amount_type
        if self.pass_through_info:
            if hasattr(self.pass_through_info, 'to_alipay_dict'):
                params['pass_through_info'] = self.pass_through_info.to_alipay_dict()
            else:
                params['pass_through_info'] = self.pass_through_info
        if self.payer_agent_id:
            if hasattr(self.payer_agent_id, 'to_alipay_dict'):
                params['payer_agent_id'] = self.payer_agent_id.to_alipay_dict()
            else:
                params['payer_agent_id'] = self.payer_agent_id
        if self.payer_payment_method:
            if hasattr(self.payer_payment_method, 'to_alipay_dict'):
                params['payer_payment_method'] = self.payer_payment_method.to_alipay_dict()
            else:
                params['payer_payment_method'] = self.payer_payment_method
        if self.transfer_from_amount:
            if hasattr(self.transfer_from_amount, 'to_alipay_dict'):
                params['transfer_from_amount'] = self.transfer_from_amount.to_alipay_dict()
            else:
                params['transfer_from_amount'] = self.transfer_from_amount
        if self.transfer_notify_url:
            if hasattr(self.transfer_notify_url, 'to_alipay_dict'):
                params['transfer_notify_url'] = self.transfer_notify_url.to_alipay_dict()
            else:
                params['transfer_notify_url'] = self.transfer_notify_url
        if self.transfer_quote:
            if hasattr(self.transfer_quote, 'to_alipay_dict'):
                params['transfer_quote'] = self.transfer_quote.to_alipay_dict()
            else:
                params['transfer_quote'] = self.transfer_quote
        if self.transfer_request_id:
            if hasattr(self.transfer_request_id, 'to_alipay_dict'):
                params['transfer_request_id'] = self.transfer_request_id.to_alipay_dict()
            else:
                params['transfer_request_id'] = self.transfer_request_id
        if self.transfer_to_amount:
            if hasattr(self.transfer_to_amount, 'to_alipay_dict'):
                params['transfer_to_amount'] = self.transfer_to_amount.to_alipay_dict()
            else:
                params['transfer_to_amount'] = self.transfer_to_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOverseasTransferConfirmModel()
        if 'additional_transfer_details' in d:
            o.additional_transfer_details = d['additional_transfer_details']
        if 'beneficiary_agent_id' in d:
            o.beneficiary_agent_id = d['beneficiary_agent_id']
        if 'beneficiary_receipt_method' in d:
            o.beneficiary_receipt_method = d['beneficiary_receipt_method']
        if 'biz_scene_type' in d:
            o.biz_scene_type = d['biz_scene_type']
        if 'instructed_amount_type' in d:
            o.instructed_amount_type = d['instructed_amount_type']
        if 'pass_through_info' in d:
            o.pass_through_info = d['pass_through_info']
        if 'payer_agent_id' in d:
            o.payer_agent_id = d['payer_agent_id']
        if 'payer_payment_method' in d:
            o.payer_payment_method = d['payer_payment_method']
        if 'transfer_from_amount' in d:
            o.transfer_from_amount = d['transfer_from_amount']
        if 'transfer_notify_url' in d:
            o.transfer_notify_url = d['transfer_notify_url']
        if 'transfer_quote' in d:
            o.transfer_quote = d['transfer_quote']
        if 'transfer_request_id' in d:
            o.transfer_request_id = d['transfer_request_id']
        if 'transfer_to_amount' in d:
            o.transfer_to_amount = d['transfer_to_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.DeliveryBaseInfo import DeliveryBaseInfo
from alipay.aop.api.domain.PromoDeliveryInfo import PromoDeliveryInfo
from alipay.aop.api.domain.DeliveryPlayConfig import DeliveryPlayConfig
from alipay.aop.api.domain.DeliveryTargetRule import DeliveryTargetRule


class AlipayMarketingActivityDeliveryQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingActivityDeliveryQueryResponse, self).__init__()
        self._delivery_base_info = None
        self._delivery_booth_code = None
        self._delivery_error_msg = None
        self._delivery_id = None
        self._delivery_info_list = None
        self._delivery_play_config = None
        self._delivery_status = None
        self._delivery_target_rule = None

    @property
    def delivery_base_info(self):
        return self._delivery_base_info

    @delivery_base_info.setter
    def delivery_base_info(self, value):
        if isinstance(value, DeliveryBaseInfo):
            self._delivery_base_info = value
        else:
            self._delivery_base_info = DeliveryBaseInfo.from_alipay_dict(value)
    @property
    def delivery_booth_code(self):
        return self._delivery_booth_code

    @delivery_booth_code.setter
    def delivery_booth_code(self, value):
        self._delivery_booth_code = value
    @property
    def delivery_error_msg(self):
        return self._delivery_error_msg

    @delivery_error_msg.setter
    def delivery_error_msg(self, value):
        self._delivery_error_msg = value
    @property
    def delivery_id(self):
        return self._delivery_id

    @delivery_id.setter
    def delivery_id(self, value):
        self._delivery_id = value
    @property
    def delivery_info_list(self):
        return self._delivery_info_list

    @delivery_info_list.setter
    def delivery_info_list(self, value):
        if isinstance(value, list):
            self._delivery_info_list = list()
            for i in value:
                if isinstance(i, PromoDeliveryInfo):
                    self._delivery_info_list.append(i)
                else:
                    self._delivery_info_list.append(PromoDeliveryInfo.from_alipay_dict(i))
    @property
    def delivery_play_config(self):
        return self._delivery_play_config

    @delivery_play_config.setter
    def delivery_play_config(self, value):
        if isinstance(value, DeliveryPlayConfig):
            self._delivery_play_config = value
        else:
            self._delivery_play_config = DeliveryPlayConfig.from_alipay_dict(value)
    @property
    def delivery_status(self):
        return self._delivery_status

    @delivery_status.setter
    def delivery_status(self, value):
        self._delivery_status = value
    @property
    def delivery_target_rule(self):
        return self._delivery_target_rule

    @delivery_target_rule.setter
    def delivery_target_rule(self, value):
        if isinstance(value, DeliveryTargetRule):
            self._delivery_target_rule = value
        else:
            self._delivery_target_rule = DeliveryTargetRule.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingActivityDeliveryQueryResponse, self).parse_response_content(response_content)
        if 'delivery_base_info' in response:
            self.delivery_base_info = response['delivery_base_info']
        if 'delivery_booth_code' in response:
            self.delivery_booth_code = response['delivery_booth_code']
        if 'delivery_error_msg' in response:
            self.delivery_error_msg = response['delivery_error_msg']
        if 'delivery_id' in response:
            self.delivery_id = response['delivery_id']
        if 'delivery_info_list' in response:
            self.delivery_info_list = response['delivery_info_list']
        if 'delivery_play_config' in response:
            self.delivery_play_config = response['delivery_play_config']
        if 'delivery_status' in response:
            self.delivery_status = response['delivery_status']
        if 'delivery_target_rule' in response:
            self.delivery_target_rule = response['delivery_target_rule']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingPassInstanceQueryModel(object):

    def __init__(self):
        self._page_num = None
        self._page_size = None
        self._pass_id = None
        self._serial_number = None
        self._tpl_id = None
        self._user_id = None

    @property
    def page_num(self):
        return self._page_num

    @page_num.setter
    def page_num(self, value):
        self._page_num = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def pass_id(self):
        return self._pass_id

    @pass_id.setter
    def pass_id(self, value):
        self._pass_id = value
    @property
    def serial_number(self):
        return self._serial_number

    @serial_number.setter
    def serial_number(self, value):
        self._serial_number = value
    @property
    def tpl_id(self):
        return self._tpl_id

    @tpl_id.setter
    def tpl_id(self, value):
        self._tpl_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.page_num:
            if hasattr(self.page_num, 'to_alipay_dict'):
                params['page_num'] = self.page_num.to_alipay_dict()
            else:
                params['page_num'] = self.page_num
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.pass_id:
            if hasattr(self.pass_id, 'to_alipay_dict'):
                params['pass_id'] = self.pass_id.to_alipay_dict()
            else:
                params['pass_id'] = self.pass_id
        if self.serial_number:
            if hasattr(self.serial_number, 'to_alipay_dict'):
                params['serial_number'] = self.serial_number.to_alipay_dict()
            else:
                params['serial_number'] = self.serial_number
        if self.tpl_id:
            if hasattr(self.tpl_id, 'to_alipay_dict'):
                params['tpl_id'] = self.tpl_id.to_alipay_dict()
            else:
                params['tpl_id'] = self.tpl_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingPassInstanceQueryModel()
        if 'page_num' in d:
            o.page_num = d['page_num']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'pass_id' in d:
            o.pass_id = d['pass_id']
        if 'serial_number' in d:
            o.serial_number = d['serial_number']
        if 'tpl_id' in d:
            o.tpl_id = d['tpl_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayEcoMycarImageUploadResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEcoMycarImageUploadResponse, self).__init__()
        self._img_id = None
        self._img_url = None

    @property
    def img_id(self):
        return self._img_id

    @img_id.setter
    def img_id(self, value):
        self._img_id = value
    @property
    def img_url(self):
        return self._img_url

    @img_url.setter
    def img_url(self, value):
        self._img_url = value

    def parse_response_content(self, response_content):
        response = super(AlipayEcoMycarImageUploadResponse, self).parse_response_content(response_content)
        if 'img_id' in response:
            self.img_id = response['img_id']
        if 'img_url' in response:
            self.img_url = response['img_url']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.SceneProdDataQueryResultDetail import SceneProdDataQueryResultDetail


class MybankCreditSceneprodDataBatchqueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditSceneprodDataBatchqueryResponse, self).__init__()
        self._result_data = None
        self._retry = None
        self._trace_id = None

    @property
    def result_data(self):
        return self._result_data

    @result_data.setter
    def result_data(self, value):
        if isinstance(value, list):
            self._result_data = list()
            for i in value:
                if isinstance(i, SceneProdDataQueryResultDetail):
                    self._result_data.append(i)
                else:
                    self._result_data.append(SceneProdDataQueryResultDetail.from_alipay_dict(i))
    @property
    def retry(self):
        return self._retry

    @retry.setter
    def retry(self, value):
        self._retry = value
    @property
    def trace_id(self):
        return self._trace_id

    @trace_id.setter
    def trace_id(self, value):
        self._trace_id = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditSceneprodDataBatchqueryResponse, self).parse_response_content(response_content)
        if 'result_data' in response:
            self.result_data = response['result_data']
        if 'retry' in response:
            self.retry = response['retry']
        if 'trace_id' in response:
            self.trace_id = response['trace_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SubVenueCreateInfo(object):

    def __init__(self):
        self._admission_requirement = None
        self._announcement = None
        self._bookable = None
        self._desc = None
        self._equipment_rental = None
        self._facility_list = None
        self._name = None
        self._opening_hours = None
        self._out_sub_venue_id = None
        self._payee_account = None
        self._payment_method = None
        self._payment_type = None
        self._phone = None
        self._picture_list = None
        self._poster = None
        self._product_type_list = None
        self._promotion = None
        self._rec_price = None
        self._sub_venue_pid = None
        self._sub_venue_smid = None
        self._tag_list = None
        self._training = None
        self._venue_type = None
        self._vip = None

    @property
    def admission_requirement(self):
        return self._admission_requirement

    @admission_requirement.setter
    def admission_requirement(self, value):
        self._admission_requirement = value
    @property
    def announcement(self):
        return self._announcement

    @announcement.setter
    def announcement(self, value):
        self._announcement = value
    @property
    def bookable(self):
        return self._bookable

    @bookable.setter
    def bookable(self, value):
        self._bookable = value
    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value
    @property
    def equipment_rental(self):
        return self._equipment_rental

    @equipment_rental.setter
    def equipment_rental(self, value):
        self._equipment_rental = value
    @property
    def facility_list(self):
        return self._facility_list

    @facility_list.setter
    def facility_list(self, value):
        if isinstance(value, list):
            self._facility_list = list()
            for i in value:
                self._facility_list.append(i)
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def opening_hours(self):
        return self._opening_hours

    @opening_hours.setter
    def opening_hours(self, value):
        self._opening_hours = value
    @property
    def out_sub_venue_id(self):
        return self._out_sub_venue_id

    @out_sub_venue_id.setter
    def out_sub_venue_id(self, value):
        self._out_sub_venue_id = value
    @property
    def payee_account(self):
        return self._payee_account

    @payee_account.setter
    def payee_account(self, value):
        self._payee_account = value
    @property
    def payment_method(self):
        return self._payment_method

    @payment_method.setter
    def payment_method(self, value):
        self._payment_method = value
    @property
    def payment_type(self):
        return self._payment_type

    @payment_type.setter
    def payment_type(self, value):
        self._payment_type = value
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        if isinstance(value, list):
            self._phone = list()
            for i in value:
                self._phone.append(i)
    @property
    def picture_list(self):
        return self._picture_list

    @picture_list.setter
    def picture_list(self, value):
        if isinstance(value, list):
            self._picture_list = list()
            for i in value:
                self._picture_list.append(i)
    @property
    def poster(self):
        return self._poster

    @poster.setter
    def poster(self, value):
        self._poster = value
    @property
    def product_type_list(self):
        return self._product_type_list

    @product_type_list.setter
    def product_type_list(self, value):
        if isinstance(value, list):
            self._product_type_list = list()
            for i in value:
                self._product_type_list.append(i)
    @property
    def promotion(self):
        return self._promotion

    @promotion.setter
    def promotion(self, value):
        self._promotion = value
    @property
    def rec_price(self):
        return self._rec_price

    @rec_price.setter
    def rec_price(self, value):
        self._rec_price = value
    @property
    def sub_venue_pid(self):
        return self._sub_venue_pid

    @sub_venue_pid.setter
    def sub_venue_pid(self, value):
        self._sub_venue_pid = value
    @property
    def sub_venue_smid(self):
        return self._sub_venue_smid

    @sub_venue_smid.setter
    def sub_venue_smid(self, value):
        self._sub_venue_smid = value
    @property
    def tag_list(self):
        return self._tag_list

    @tag_list.setter
    def tag_list(self, value):
        if isinstance(value, list):
            self._tag_list = list()
            for i in value:
                self._tag_list.append(i)
    @property
    def training(self):
        return self._training

    @training.setter
    def training(self, value):
        self._training = value
    @property
    def venue_type(self):
        return self._venue_type

    @venue_type.setter
    def venue_type(self, value):
        self._venue_type = value
    @property
    def vip(self):
        return self._vip

    @vip.setter
    def vip(self, value):
        self._vip = value


    def to_alipay_dict(self):
        params = dict()
        if self.admission_requirement:
            if hasattr(self.admission_requirement, 'to_alipay_dict'):
                params['admission_requirement'] = self.admission_requirement.to_alipay_dict()
            else:
                params['admission_requirement'] = self.admission_requirement
        if self.announcement:
            if hasattr(self.announcement, 'to_alipay_dict'):
                params['announcement'] = self.announcement.to_alipay_dict()
            else:
                params['announcement'] = self.announcement
        if self.bookable:
            if hasattr(self.bookable, 'to_alipay_dict'):
                params['bookable'] = self.bookable.to_alipay_dict()
            else:
                params['bookable'] = self.bookable
        if self.desc:
            if hasattr(self.desc, 'to_alipay_dict'):
                params['desc'] = self.desc.to_alipay_dict()
            else:
                params['desc'] = self.desc
        if self.equipment_rental:
            if hasattr(self.equipment_rental, 'to_alipay_dict'):
                params['equipment_rental'] = self.equipment_rental.to_alipay_dict()
            else:
                params['equipment_rental'] = self.equipment_rental
        if self.facility_list:
            if isinstance(self.facility_list, list):
                for i in range(0, len(self.facility_list)):
                    element = self.facility_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.facility_list[i] = element.to_alipay_dict()
            if hasattr(self.facility_list, 'to_alipay_dict'):
                params['facility_list'] = self.facility_list.to_alipay_dict()
            else:
                params['facility_list'] = self.facility_list
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.opening_hours:
            if hasattr(self.opening_hours, 'to_alipay_dict'):
                params['opening_hours'] = self.opening_hours.to_alipay_dict()
            else:
                params['opening_hours'] = self.opening_hours
        if self.out_sub_venue_id:
            if hasattr(self.out_sub_venue_id, 'to_alipay_dict'):
                params['out_sub_venue_id'] = self.out_sub_venue_id.to_alipay_dict()
            else:
                params['out_sub_venue_id'] = self.out_sub_venue_id
        if self.payee_account:
            if hasattr(self.payee_account, 'to_alipay_dict'):
                params['payee_account'] = self.payee_account.to_alipay_dict()
            else:
                params['payee_account'] = self.payee_account
        if self.payment_method:
            if hasattr(self.payment_method, 'to_alipay_dict'):
                params['payment_method'] = self.payment_method.to_alipay_dict()
            else:
                params['payment_method'] = self.payment_method
        if self.payment_type:
            if hasattr(self.payment_type, 'to_alipay_dict'):
                params['payment_type'] = self.payment_type.to_alipay_dict()
            else:
                params['payment_type'] = self.payment_type
        if self.phone:
            if isinstance(self.phone, list):
                for i in range(0, len(self.phone)):
                    element = self.phone[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.phone[i] = element.to_alipay_dict()
            if hasattr(self.phone, 'to_alipay_dict'):
                params['phone'] = self.phone.to_alipay_dict()
            else:
                params['phone'] = self.phone
        if self.picture_list:
            if isinstance(self.picture_list, list):
                for i in range(0, len(self.picture_list)):
                    element = self.picture_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.picture_list[i] = element.to_alipay_dict()
            if hasattr(self.picture_list, 'to_alipay_dict'):
                params['picture_list'] = self.picture_list.to_alipay_dict()
            else:
                params['picture_list'] = self.picture_list
        if self.poster:
            if hasattr(self.poster, 'to_alipay_dict'):
                params['poster'] = self.poster.to_alipay_dict()
            else:
                params['poster'] = self.poster
        if self.product_type_list:
            if isinstance(self.product_type_list, list):
                for i in range(0, len(self.product_type_list)):
                    element = self.product_type_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.product_type_list[i] = element.to_alipay_dict()
            if hasattr(self.product_type_list, 'to_alipay_dict'):
                params['product_type_list'] = self.product_type_list.to_alipay_dict()
            else:
                params['product_type_list'] = self.product_type_list
        if self.promotion:
            if hasattr(self.promotion, 'to_alipay_dict'):
                params['promotion'] = self.promotion.to_alipay_dict()
            else:
                params['promotion'] = self.promotion
        if self.rec_price:
            if hasattr(self.rec_price, 'to_alipay_dict'):
                params['rec_price'] = self.rec_price.to_alipay_dict()
            else:
                params['rec_price'] = self.rec_price
        if self.sub_venue_pid:
            if hasattr(self.sub_venue_pid, 'to_alipay_dict'):
                params['sub_venue_pid'] = self.sub_venue_pid.to_alipay_dict()
            else:
                params['sub_venue_pid'] = self.sub_venue_pid
        if self.sub_venue_smid:
            if hasattr(self.sub_venue_smid, 'to_alipay_dict'):
                params['sub_venue_smid'] = self.sub_venue_smid.to_alipay_dict()
            else:
                params['sub_venue_smid'] = self.sub_venue_smid
        if self.tag_list:
            if isinstance(self.tag_list, list):
                for i in range(0, len(self.tag_list)):
                    element = self.tag_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.tag_list[i] = element.to_alipay_dict()
            if hasattr(self.tag_list, 'to_alipay_dict'):
                params['tag_list'] = self.tag_list.to_alipay_dict()
            else:
                params['tag_list'] = self.tag_list
        if self.training:
            if hasattr(self.training, 'to_alipay_dict'):
                params['training'] = self.training.to_alipay_dict()
            else:
                params['training'] = self.training
        if self.venue_type:
            if hasattr(self.venue_type, 'to_alipay_dict'):
                params['venue_type'] = self.venue_type.to_alipay_dict()
            else:
                params['venue_type'] = self.venue_type
        if self.vip:
            if hasattr(self.vip, 'to_alipay_dict'):
                params['vip'] = self.vip.to_alipay_dict()
            else:
                params['vip'] = self.vip
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SubVenueCreateInfo()
        if 'admission_requirement' in d:
            o.admission_requirement = d['admission_requirement']
        if 'announcement' in d:
            o.announcement = d['announcement']
        if 'bookable' in d:
            o.bookable = d['bookable']
        if 'desc' in d:
            o.desc = d['desc']
        if 'equipment_rental' in d:
            o.equipment_rental = d['equipment_rental']
        if 'facility_list' in d:
            o.facility_list = d['facility_list']
        if 'name' in d:
            o.name = d['name']
        if 'opening_hours' in d:
            o.opening_hours = d['opening_hours']
        if 'out_sub_venue_id' in d:
            o.out_sub_venue_id = d['out_sub_venue_id']
        if 'payee_account' in d:
            o.payee_account = d['payee_account']
        if 'payment_method' in d:
            o.payment_method = d['payment_method']
        if 'payment_type' in d:
            o.payment_type = d['payment_type']
        if 'phone' in d:
            o.phone = d['phone']
        if 'picture_list' in d:
            o.picture_list = d['picture_list']
        if 'poster' in d:
            o.poster = d['poster']
        if 'product_type_list' in d:
            o.product_type_list = d['product_type_list']
        if 'promotion' in d:
            o.promotion = d['promotion']
        if 'rec_price' in d:
            o.rec_price = d['rec_price']
        if 'sub_venue_pid' in d:
            o.sub_venue_pid = d['sub_venue_pid']
        if 'sub_venue_smid' in d:
            o.sub_venue_smid = d['sub_venue_smid']
        if 'tag_list' in d:
            o.tag_list = d['tag_list']
        if 'training' in d:
            o.training = d['training']
        if 'venue_type' in d:
            o.venue_type = d['venue_type']
        if 'vip' in d:
            o.vip = d['vip']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AdCreativeResult import AdCreativeResult


class AlipayCommerceTransportAdCreativeQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportAdCreativeQueryResponse, self).__init__()
        self._ad_creative_result = None

    @property
    def ad_creative_result(self):
        return self._ad_creative_result

    @ad_creative_result.setter
    def ad_creative_result(self, value):
        if isinstance(value, AdCreativeResult):
            self._ad_creative_result = value
        else:
            self._ad_creative_result = AdCreativeResult.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportAdCreativeQueryResponse, self).parse_response_content(response_content)
        if 'ad_creative_result' in response:
            self.ad_creative_result = response['ad_creative_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayPcreditHuabeiEnterpriseUserinfoSyncModel(object):

    def __init__(self):
        self._agreement_id = None
        self._alipay_user_id = None
        self._dept_name = None
        self._employee_count = None
        self._employee_level = None
        self._employee_name = None
        self._employee_position = None
        self._entry_time = None
        self._identity_no = None
        self._mail_addr = None
        self._management = None
        self._mobile_no = None
        self._partner_id = None

    @property
    def agreement_id(self):
        return self._agreement_id

    @agreement_id.setter
    def agreement_id(self, value):
        self._agreement_id = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def dept_name(self):
        return self._dept_name

    @dept_name.setter
    def dept_name(self, value):
        self._dept_name = value
    @property
    def employee_count(self):
        return self._employee_count

    @employee_count.setter
    def employee_count(self, value):
        self._employee_count = value
    @property
    def employee_level(self):
        return self._employee_level

    @employee_level.setter
    def employee_level(self, value):
        self._employee_level = value
    @property
    def employee_name(self):
        return self._employee_name

    @employee_name.setter
    def employee_name(self, value):
        self._employee_name = value
    @property
    def employee_position(self):
        return self._employee_position

    @employee_position.setter
    def employee_position(self, value):
        self._employee_position = value
    @property
    def entry_time(self):
        return self._entry_time

    @entry_time.setter
    def entry_time(self, value):
        self._entry_time = value
    @property
    def identity_no(self):
        return self._identity_no

    @identity_no.setter
    def identity_no(self, value):
        self._identity_no = value
    @property
    def mail_addr(self):
        return self._mail_addr

    @mail_addr.setter
    def mail_addr(self, value):
        self._mail_addr = value
    @property
    def management(self):
        return self._management

    @management.setter
    def management(self, value):
        self._management = value
    @property
    def mobile_no(self):
        return self._mobile_no

    @mobile_no.setter
    def mobile_no(self, value):
        self._mobile_no = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.agreement_id:
            if hasattr(self.agreement_id, 'to_alipay_dict'):
                params['agreement_id'] = self.agreement_id.to_alipay_dict()
            else:
                params['agreement_id'] = self.agreement_id
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.dept_name:
            if hasattr(self.dept_name, 'to_alipay_dict'):
                params['dept_name'] = self.dept_name.to_alipay_dict()
            else:
                params['dept_name'] = self.dept_name
        if self.employee_count:
            if hasattr(self.employee_count, 'to_alipay_dict'):
                params['employee_count'] = self.employee_count.to_alipay_dict()
            else:
                params['employee_count'] = self.employee_count
        if self.employee_level:
            if hasattr(self.employee_level, 'to_alipay_dict'):
                params['employee_level'] = self.employee_level.to_alipay_dict()
            else:
                params['employee_level'] = self.employee_level
        if self.employee_name:
            if hasattr(self.employee_name, 'to_alipay_dict'):
                params['employee_name'] = self.employee_name.to_alipay_dict()
            else:
                params['employee_name'] = self.employee_name
        if self.employee_position:
            if hasattr(self.employee_position, 'to_alipay_dict'):
                params['employee_position'] = self.employee_position.to_alipay_dict()
            else:
                params['employee_position'] = self.employee_position
        if self.entry_time:
            if hasattr(self.entry_time, 'to_alipay_dict'):
                params['entry_time'] = self.entry_time.to_alipay_dict()
            else:
                params['entry_time'] = self.entry_time
        if self.identity_no:
            if hasattr(self.identity_no, 'to_alipay_dict'):
                params['identity_no'] = self.identity_no.to_alipay_dict()
            else:
                params['identity_no'] = self.identity_no
        if self.mail_addr:
            if hasattr(self.mail_addr, 'to_alipay_dict'):
                params['mail_addr'] = self.mail_addr.to_alipay_dict()
            else:
                params['mail_addr'] = self.mail_addr
        if self.management:
            if hasattr(self.management, 'to_alipay_dict'):
                params['management'] = self.management.to_alipay_dict()
            else:
                params['management'] = self.management
        if self.mobile_no:
            if hasattr(self.mobile_no, 'to_alipay_dict'):
                params['mobile_no'] = self.mobile_no.to_alipay_dict()
            else:
                params['mobile_no'] = self.mobile_no
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayPcreditHuabeiEnterpriseUserinfoSyncModel()
        if 'agreement_id' in d:
            o.agreement_id = d['agreement_id']
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'dept_name' in d:
            o.dept_name = d['dept_name']
        if 'employee_count' in d:
            o.employee_count = d['employee_count']
        if 'employee_level' in d:
            o.employee_level = d['employee_level']
        if 'employee_name' in d:
            o.employee_name = d['employee_name']
        if 'employee_position' in d:
            o.employee_position = d['employee_position']
        if 'entry_time' in d:
            o.entry_time = d['entry_time']
        if 'identity_no' in d:
            o.identity_no = d['identity_no']
        if 'mail_addr' in d:
            o.mail_addr = d['mail_addr']
        if 'management' in d:
            o.management = d['management']
        if 'mobile_no' in d:
            o.mobile_no = d['mobile_no']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppFlowQualificationDetectModel(object):

    def __init__(self):
        self._mobile = None
        self._product_id = None
        self._user_id = None

    @property
    def mobile(self):
        return self._mobile

    @mobile.setter
    def mobile(self, value):
        self._mobile = value
    @property
    def product_id(self):
        return self._product_id

    @product_id.setter
    def product_id(self, value):
        if isinstance(value, list):
            self._product_id = list()
            for i in value:
                self._product_id.append(i)
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.mobile:
            if hasattr(self.mobile, 'to_alipay_dict'):
                params['mobile'] = self.mobile.to_alipay_dict()
            else:
                params['mobile'] = self.mobile
        if self.product_id:
            if isinstance(self.product_id, list):
                for i in range(0, len(self.product_id)):
                    element = self.product_id[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.product_id[i] = element.to_alipay_dict()
            if hasattr(self.product_id, 'to_alipay_dict'):
                params['product_id'] = self.product_id.to_alipay_dict()
            else:
                params['product_id'] = self.product_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppFlowQualificationDetectModel()
        if 'mobile' in d:
            o.mobile = d['mobile']
        if 'product_id' in d:
            o.product_id = d['product_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BusinessLicenseCertFileds(object):

    def __init__(self):
        self._creditcode = None
        self._entname = None

    @property
    def creditcode(self):
        return self._creditcode

    @creditcode.setter
    def creditcode(self, value):
        self._creditcode = value
    @property
    def entname(self):
        return self._entname

    @entname.setter
    def entname(self, value):
        self._entname = value


    def to_alipay_dict(self):
        params = dict()
        if self.creditcode:
            if hasattr(self.creditcode, 'to_alipay_dict'):
                params['creditcode'] = self.creditcode.to_alipay_dict()
            else:
                params['creditcode'] = self.creditcode
        if self.entname:
            if hasattr(self.entname, 'to_alipay_dict'):
                params['entname'] = self.entname.to_alipay_dict()
            else:
                params['entname'] = self.entname
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BusinessLicenseCertFileds()
        if 'creditcode' in d:
            o.creditcode = d['creditcode']
        if 'entname' in d:
            o.entname = d['entname']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OrderExtendParams(object):

    def __init__(self):
        self._cashier_result_render_url = None
        self._out_scene_biz_no = None
        self._platform_scheme_ar_no = None
        self._seller_scheme_ar_no = None

    @property
    def cashier_result_render_url(self):
        return self._cashier_result_render_url

    @cashier_result_render_url.setter
    def cashier_result_render_url(self, value):
        self._cashier_result_render_url = value
    @property
    def out_scene_biz_no(self):
        return self._out_scene_biz_no

    @out_scene_biz_no.setter
    def out_scene_biz_no(self, value):
        self._out_scene_biz_no = value
    @property
    def platform_scheme_ar_no(self):
        return self._platform_scheme_ar_no

    @platform_scheme_ar_no.setter
    def platform_scheme_ar_no(self, value):
        self._platform_scheme_ar_no = value
    @property
    def seller_scheme_ar_no(self):
        return self._seller_scheme_ar_no

    @seller_scheme_ar_no.setter
    def seller_scheme_ar_no(self, value):
        self._seller_scheme_ar_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.cashier_result_render_url:
            if hasattr(self.cashier_result_render_url, 'to_alipay_dict'):
                params['cashier_result_render_url'] = self.cashier_result_render_url.to_alipay_dict()
            else:
                params['cashier_result_render_url'] = self.cashier_result_render_url
        if self.out_scene_biz_no:
            if hasattr(self.out_scene_biz_no, 'to_alipay_dict'):
                params['out_scene_biz_no'] = self.out_scene_biz_no.to_alipay_dict()
            else:
                params['out_scene_biz_no'] = self.out_scene_biz_no
        if self.platform_scheme_ar_no:
            if hasattr(self.platform_scheme_ar_no, 'to_alipay_dict'):
                params['platform_scheme_ar_no'] = self.platform_scheme_ar_no.to_alipay_dict()
            else:
                params['platform_scheme_ar_no'] = self.platform_scheme_ar_no
        if self.seller_scheme_ar_no:
            if hasattr(self.seller_scheme_ar_no, 'to_alipay_dict'):
                params['seller_scheme_ar_no'] = self.seller_scheme_ar_no.to_alipay_dict()
            else:
                params['seller_scheme_ar_no'] = self.seller_scheme_ar_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OrderExtendParams()
        if 'cashier_result_render_url' in d:
            o.cashier_result_render_url = d['cashier_result_render_url']
        if 'out_scene_biz_no' in d:
            o.out_scene_biz_no = d['out_scene_biz_no']
        if 'platform_scheme_ar_no' in d:
            o.platform_scheme_ar_no = d['platform_scheme_ar_no']
        if 'seller_scheme_ar_no' in d:
            o.seller_scheme_ar_no = d['seller_scheme_ar_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BillAmtVo import BillAmtVo
from alipay.aop.api.domain.BillAmtVo import BillAmtVo
from alipay.aop.api.domain.MultiCurrencyMoneyVO import MultiCurrencyMoneyVO


class BillDetailVo(object):

    def __init__(self):
        self._bill_account_date = None
        self._bill_balance_detail = None
        self._bill_create_date = None
        self._bill_no = None
        self._bill_repay_detail = None
        self._bill_status = None
        self._clear_date = None
        self._repay_date = None
        self._total_prin_amt = None

    @property
    def bill_account_date(self):
        return self._bill_account_date

    @bill_account_date.setter
    def bill_account_date(self, value):
        self._bill_account_date = value
    @property
    def bill_balance_detail(self):
        return self._bill_balance_detail

    @bill_balance_detail.setter
    def bill_balance_detail(self, value):
        if isinstance(value, BillAmtVo):
            self._bill_balance_detail = value
        else:
            self._bill_balance_detail = BillAmtVo.from_alipay_dict(value)
    @property
    def bill_create_date(self):
        return self._bill_create_date

    @bill_create_date.setter
    def bill_create_date(self, value):
        self._bill_create_date = value
    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def bill_repay_detail(self):
        return self._bill_repay_detail

    @bill_repay_detail.setter
    def bill_repay_detail(self, value):
        if isinstance(value, BillAmtVo):
            self._bill_repay_detail = value
        else:
            self._bill_repay_detail = BillAmtVo.from_alipay_dict(value)
    @property
    def bill_status(self):
        return self._bill_status

    @bill_status.setter
    def bill_status(self, value):
        self._bill_status = value
    @property
    def clear_date(self):
        return self._clear_date

    @clear_date.setter
    def clear_date(self, value):
        self._clear_date = value
    @property
    def repay_date(self):
        return self._repay_date

    @repay_date.setter
    def repay_date(self, value):
        self._repay_date = value
    @property
    def total_prin_amt(self):
        return self._total_prin_amt

    @total_prin_amt.setter
    def total_prin_amt(self, value):
        if isinstance(value, MultiCurrencyMoneyVO):
            self._total_prin_amt = value
        else:
            self._total_prin_amt = MultiCurrencyMoneyVO.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.bill_account_date:
            if hasattr(self.bill_account_date, 'to_alipay_dict'):
                params['bill_account_date'] = self.bill_account_date.to_alipay_dict()
            else:
                params['bill_account_date'] = self.bill_account_date
        if self.bill_balance_detail:
            if hasattr(self.bill_balance_detail, 'to_alipay_dict'):
                params['bill_balance_detail'] = self.bill_balance_detail.to_alipay_dict()
            else:
                params['bill_balance_detail'] = self.bill_balance_detail
        if self.bill_create_date:
            if hasattr(self.bill_create_date, 'to_alipay_dict'):
                params['bill_create_date'] = self.bill_create_date.to_alipay_dict()
            else:
                params['bill_create_date'] = self.bill_create_date
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.bill_repay_detail:
            if hasattr(self.bill_repay_detail, 'to_alipay_dict'):
                params['bill_repay_detail'] = self.bill_repay_detail.to_alipay_dict()
            else:
                params['bill_repay_detail'] = self.bill_repay_detail
        if self.bill_status:
            if hasattr(self.bill_status, 'to_alipay_dict'):
                params['bill_status'] = self.bill_status.to_alipay_dict()
            else:
                params['bill_status'] = self.bill_status
        if self.clear_date:
            if hasattr(self.clear_date, 'to_alipay_dict'):
                params['clear_date'] = self.clear_date.to_alipay_dict()
            else:
                params['clear_date'] = self.clear_date
        if self.repay_date:
            if hasattr(self.repay_date, 'to_alipay_dict'):
                params['repay_date'] = self.repay_date.to_alipay_dict()
            else:
                params['repay_date'] = self.repay_date
        if self.total_prin_amt:
            if hasattr(self.total_prin_amt, 'to_alipay_dict'):
                params['total_prin_amt'] = self.total_prin_amt.to_alipay_dict()
            else:
                params['total_prin_amt'] = self.total_prin_amt
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BillDetailVo()
        if 'bill_account_date' in d:
            o.bill_account_date = d['bill_account_date']
        if 'bill_balance_detail' in d:
            o.bill_balance_detail = d['bill_balance_detail']
        if 'bill_create_date' in d:
            o.bill_create_date = d['bill_create_date']
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'bill_repay_detail' in d:
            o.bill_repay_detail = d['bill_repay_detail']
        if 'bill_status' in d:
            o.bill_status = d['bill_status']
        if 'clear_date' in d:
            o.clear_date = d['clear_date']
        if 'repay_date' in d:
            o.repay_date = d['repay_date']
        if 'total_prin_amt' in d:
            o.total_prin_amt = d['total_prin_amt']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenIotbpaasDevicebindApplyModel(object):

    def __init__(self):
        self._bind_token = None
        self._type = None

    @property
    def bind_token(self):
        return self._bind_token

    @bind_token.setter
    def bind_token(self, value):
        self._bind_token = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.bind_token:
            if hasattr(self.bind_token, 'to_alipay_dict'):
                params['bind_token'] = self.bind_token.to_alipay_dict()
            else:
                params['bind_token'] = self.bind_token
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenIotbpaasDevicebindApplyModel()
        if 'bind_token' in d:
            o.bind_token = d['bind_token']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataDataserviceDmpserviceCreateModel(object):

    def __init__(self):
        self._conversion_id = None
        self._conversion_time = None
        self._conversion_type = None
        self._device_id = None
        self._device_type = None
        self._event_type = None
        self._ext_info = None
        self._is_conversion = None
        self._request_id = None
        self._source = None
        self._track_url = None
        self._user_id = None

    @property
    def conversion_id(self):
        return self._conversion_id

    @conversion_id.setter
    def conversion_id(self, value):
        self._conversion_id = value
    @property
    def conversion_time(self):
        return self._conversion_time

    @conversion_time.setter
    def conversion_time(self, value):
        self._conversion_time = value
    @property
    def conversion_type(self):
        return self._conversion_type

    @conversion_type.setter
    def conversion_type(self, value):
        self._conversion_type = value
    @property
    def device_id(self):
        return self._device_id

    @device_id.setter
    def device_id(self, value):
        self._device_id = value
    @property
    def device_type(self):
        return self._device_type

    @device_type.setter
    def device_type(self, value):
        self._device_type = value
    @property
    def event_type(self):
        return self._event_type

    @event_type.setter
    def event_type(self, value):
        self._event_type = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def is_conversion(self):
        return self._is_conversion

    @is_conversion.setter
    def is_conversion(self, value):
        self._is_conversion = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def track_url(self):
        return self._track_url

    @track_url.setter
    def track_url(self, value):
        self._track_url = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.conversion_id:
            if hasattr(self.conversion_id, 'to_alipay_dict'):
                params['conversion_id'] = self.conversion_id.to_alipay_dict()
            else:
                params['conversion_id'] = self.conversion_id
        if self.conversion_time:
            if hasattr(self.conversion_time, 'to_alipay_dict'):
                params['conversion_time'] = self.conversion_time.to_alipay_dict()
            else:
                params['conversion_time'] = self.conversion_time
        if self.conversion_type:
            if hasattr(self.conversion_type, 'to_alipay_dict'):
                params['conversion_type'] = self.conversion_type.to_alipay_dict()
            else:
                params['conversion_type'] = self.conversion_type
        if self.device_id:
            if hasattr(self.device_id, 'to_alipay_dict'):
                params['device_id'] = self.device_id.to_alipay_dict()
            else:
                params['device_id'] = self.device_id
        if self.device_type:
            if hasattr(self.device_type, 'to_alipay_dict'):
                params['device_type'] = self.device_type.to_alipay_dict()
            else:
                params['device_type'] = self.device_type
        if self.event_type:
            if hasattr(self.event_type, 'to_alipay_dict'):
                params['event_type'] = self.event_type.to_alipay_dict()
            else:
                params['event_type'] = self.event_type
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.is_conversion:
            if hasattr(self.is_conversion, 'to_alipay_dict'):
                params['is_conversion'] = self.is_conversion.to_alipay_dict()
            else:
                params['is_conversion'] = self.is_conversion
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.track_url:
            if hasattr(self.track_url, 'to_alipay_dict'):
                params['track_url'] = self.track_url.to_alipay_dict()
            else:
                params['track_url'] = self.track_url
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataDataserviceDmpserviceCreateModel()
        if 'conversion_id' in d:
            o.conversion_id = d['conversion_id']
        if 'conversion_time' in d:
            o.conversion_time = d['conversion_time']
        if 'conversion_type' in d:
            o.conversion_type = d['conversion_type']
        if 'device_id' in d:
            o.device_id = d['device_id']
        if 'device_type' in d:
            o.device_type = d['device_type']
        if 'event_type' in d:
            o.event_type = d['event_type']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'is_conversion' in d:
            o.is_conversion = d['is_conversion']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'source' in d:
            o.source = d['source']
        if 'track_url' in d:
            o.track_url = d['track_url']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserQuanyibaoOpenbenefitSendResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserQuanyibaoOpenbenefitSendResponse, self).__init__()
        self._send_biz_no = None
        self._send_status = None

    @property
    def send_biz_no(self):
        return self._send_biz_no

    @send_biz_no.setter
    def send_biz_no(self, value):
        self._send_biz_no = value
    @property
    def send_status(self):
        return self._send_status

    @send_status.setter
    def send_status(self, value):
        self._send_status = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserQuanyibaoOpenbenefitSendResponse, self).parse_response_content(response_content)
        if 'send_biz_no' in response:
            self.send_biz_no = response['send_biz_no']
        if 'send_status' in response:
            self.send_status = response['send_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMarketingToolSignupQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMarketingToolSignupQueryResponse, self).__init__()
        self._play_id = None
        self._sign_up = None

    @property
    def play_id(self):
        return self._play_id

    @play_id.setter
    def play_id(self, value):
        self._play_id = value
    @property
    def sign_up(self):
        return self._sign_up

    @sign_up.setter
    def sign_up(self, value):
        self._sign_up = value

    def parse_response_content(self, response_content):
        response = super(AlipayMarketingToolSignupQueryResponse, self).parse_response_content(response_content)
        if 'play_id' in response:
            self.play_id = response['play_id']
        if 'sign_up' in response:
            self.sign_up = response['sign_up']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Attachment import Attachment
from alipay.aop.api.domain.ConfigInfo import ConfigInfo
from alipay.aop.api.domain.TemplateInfo import TemplateInfo


class AlipayEcoSignFlowCreateModel(object):

    def __init__(self):
        self._attachments = None
        self._business_scene = None
        self._config_info = None
        self._template_infos = None

    @property
    def attachments(self):
        return self._attachments

    @attachments.setter
    def attachments(self, value):
        if isinstance(value, list):
            self._attachments = list()
            for i in value:
                if isinstance(i, Attachment):
                    self._attachments.append(i)
                else:
                    self._attachments.append(Attachment.from_alipay_dict(i))
    @property
    def business_scene(self):
        return self._business_scene

    @business_scene.setter
    def business_scene(self, value):
        self._business_scene = value
    @property
    def config_info(self):
        return self._config_info

    @config_info.setter
    def config_info(self, value):
        if isinstance(value, ConfigInfo):
            self._config_info = value
        else:
            self._config_info = ConfigInfo.from_alipay_dict(value)
    @property
    def template_infos(self):
        return self._template_infos

    @template_infos.setter
    def template_infos(self, value):
        if isinstance(value, list):
            self._template_infos = list()
            for i in value:
                if isinstance(i, TemplateInfo):
                    self._template_infos.append(i)
                else:
                    self._template_infos.append(TemplateInfo.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.attachments:
            if isinstance(self.attachments, list):
                for i in range(0, len(self.attachments)):
                    element = self.attachments[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.attachments[i] = element.to_alipay_dict()
            if hasattr(self.attachments, 'to_alipay_dict'):
                params['attachments'] = self.attachments.to_alipay_dict()
            else:
                params['attachments'] = self.attachments
        if self.business_scene:
            if hasattr(self.business_scene, 'to_alipay_dict'):
                params['business_scene'] = self.business_scene.to_alipay_dict()
            else:
                params['business_scene'] = self.business_scene
        if self.config_info:
            if hasattr(self.config_info, 'to_alipay_dict'):
                params['config_info'] = self.config_info.to_alipay_dict()
            else:
                params['config_info'] = self.config_info
        if self.template_infos:
            if isinstance(self.template_infos, list):
                for i in range(0, len(self.template_infos)):
                    element = self.template_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.template_infos[i] = element.to_alipay_dict()
            if hasattr(self.template_infos, 'to_alipay_dict'):
                params['template_infos'] = self.template_infos.to_alipay_dict()
            else:
                params['template_infos'] = self.template_infos
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoSignFlowCreateModel()
        if 'attachments' in d:
            o.attachments = d['attachments']
        if 'business_scene' in d:
            o.business_scene = d['business_scene']
        if 'config_info' in d:
            o.config_info = d['config_info']
        if 'template_infos' in d:
            o.template_infos = d['template_infos']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class TemplateRemindDTO(object):

    def __init__(self):
        self._offset = None

    @property
    def offset(self):
        return self._offset

    @offset.setter
    def offset(self, value):
        self._offset = value


    def to_alipay_dict(self):
        params = dict()
        if self.offset:
            if hasattr(self.offset, 'to_alipay_dict'):
                params['offset'] = self.offset.to_alipay_dict()
            else:
                params['offset'] = self.offset
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = TemplateRemindDTO()
        if 'offset' in d:
            o.offset = d['offset']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BizResData(object):

    def __init__(self):
        self._biz_amount = None
        self._biz_date = None
        self._biz_no = None
        self._biz_user_id = None

    @property
    def biz_amount(self):
        return self._biz_amount

    @biz_amount.setter
    def biz_amount(self, value):
        self._biz_amount = value
    @property
    def biz_date(self):
        return self._biz_date

    @biz_date.setter
    def biz_date(self, value):
        self._biz_date = value
    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def biz_user_id(self):
        return self._biz_user_id

    @biz_user_id.setter
    def biz_user_id(self, value):
        self._biz_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_amount:
            if hasattr(self.biz_amount, 'to_alipay_dict'):
                params['biz_amount'] = self.biz_amount.to_alipay_dict()
            else:
                params['biz_amount'] = self.biz_amount
        if self.biz_date:
            if hasattr(self.biz_date, 'to_alipay_dict'):
                params['biz_date'] = self.biz_date.to_alipay_dict()
            else:
                params['biz_date'] = self.biz_date
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.biz_user_id:
            if hasattr(self.biz_user_id, 'to_alipay_dict'):
                params['biz_user_id'] = self.biz_user_id.to_alipay_dict()
            else:
                params['biz_user_id'] = self.biz_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BizResData()
        if 'biz_amount' in d:
            o.biz_amount = d['biz_amount']
        if 'biz_date' in d:
            o.biz_date = d['biz_date']
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'biz_user_id' in d:
            o.biz_user_id = d['biz_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommercePromoterRelationCreateModel(object):

    def __init__(self):
        self._merchant_pid = None
        self._mini_app_id = None
        self._promoter_id = None
        self._role = None
        self._shop_id = None
        self._store_id = None

    @property
    def merchant_pid(self):
        return self._merchant_pid

    @merchant_pid.setter
    def merchant_pid(self, value):
        self._merchant_pid = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def promoter_id(self):
        return self._promoter_id

    @promoter_id.setter
    def promoter_id(self, value):
        self._promoter_id = value
    @property
    def role(self):
        return self._role

    @role.setter
    def role(self, value):
        self._role = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def store_id(self):
        return self._store_id

    @store_id.setter
    def store_id(self, value):
        self._store_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.merchant_pid:
            if hasattr(self.merchant_pid, 'to_alipay_dict'):
                params['merchant_pid'] = self.merchant_pid.to_alipay_dict()
            else:
                params['merchant_pid'] = self.merchant_pid
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.promoter_id:
            if hasattr(self.promoter_id, 'to_alipay_dict'):
                params['promoter_id'] = self.promoter_id.to_alipay_dict()
            else:
                params['promoter_id'] = self.promoter_id
        if self.role:
            if hasattr(self.role, 'to_alipay_dict'):
                params['role'] = self.role.to_alipay_dict()
            else:
                params['role'] = self.role
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.store_id:
            if hasattr(self.store_id, 'to_alipay_dict'):
                params['store_id'] = self.store_id.to_alipay_dict()
            else:
                params['store_id'] = self.store_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommercePromoterRelationCreateModel()
        if 'merchant_pid' in d:
            o.merchant_pid = d['merchant_pid']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'promoter_id' in d:
            o.promoter_id = d['promoter_id']
        if 'role' in d:
            o.role = d['role']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'store_id' in d:
            o.store_id = d['store_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenSearchBoxactivityApplyResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenSearchBoxactivityApplyResponse, self).__init__()
        self._box_activity_id = None

    @property
    def box_activity_id(self):
        return self._box_activity_id

    @box_activity_id.setter
    def box_activity_id(self, value):
        self._box_activity_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayOpenSearchBoxactivityApplyResponse, self).parse_response_content(response_content)
        if 'box_activity_id' in response:
            self.box_activity_id = response['box_activity_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDataAiserviceCloudbusSchedualtaskAddModel(object):

    def __init__(self):
        self._app_version = None
        self._city_code = None
        self._corp_id = None
        self._down_bus_cnt = None
        self._ext_param = None
        self._line_id = None
        self._partner_id = None
        self._task_name = None
        self._time_table_pid = None
        self._up_bus_cnt = None

    @property
    def app_version(self):
        return self._app_version

    @app_version.setter
    def app_version(self, value):
        self._app_version = value
    @property
    def city_code(self):
        return self._city_code

    @city_code.setter
    def city_code(self, value):
        self._city_code = value
    @property
    def corp_id(self):
        return self._corp_id

    @corp_id.setter
    def corp_id(self, value):
        self._corp_id = value
    @property
    def down_bus_cnt(self):
        return self._down_bus_cnt

    @down_bus_cnt.setter
    def down_bus_cnt(self, value):
        self._down_bus_cnt = value
    @property
    def ext_param(self):
        return self._ext_param

    @ext_param.setter
    def ext_param(self, value):
        self._ext_param = value
    @property
    def line_id(self):
        return self._line_id

    @line_id.setter
    def line_id(self, value):
        self._line_id = value
    @property
    def partner_id(self):
        return self._partner_id

    @partner_id.setter
    def partner_id(self, value):
        self._partner_id = value
    @property
    def task_name(self):
        return self._task_name

    @task_name.setter
    def task_name(self, value):
        self._task_name = value
    @property
    def time_table_pid(self):
        return self._time_table_pid

    @time_table_pid.setter
    def time_table_pid(self, value):
        self._time_table_pid = value
    @property
    def up_bus_cnt(self):
        return self._up_bus_cnt

    @up_bus_cnt.setter
    def up_bus_cnt(self, value):
        self._up_bus_cnt = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_version:
            if hasattr(self.app_version, 'to_alipay_dict'):
                params['app_version'] = self.app_version.to_alipay_dict()
            else:
                params['app_version'] = self.app_version
        if self.city_code:
            if hasattr(self.city_code, 'to_alipay_dict'):
                params['city_code'] = self.city_code.to_alipay_dict()
            else:
                params['city_code'] = self.city_code
        if self.corp_id:
            if hasattr(self.corp_id, 'to_alipay_dict'):
                params['corp_id'] = self.corp_id.to_alipay_dict()
            else:
                params['corp_id'] = self.corp_id
        if self.down_bus_cnt:
            if hasattr(self.down_bus_cnt, 'to_alipay_dict'):
                params['down_bus_cnt'] = self.down_bus_cnt.to_alipay_dict()
            else:
                params['down_bus_cnt'] = self.down_bus_cnt
        if self.ext_param:
            if hasattr(self.ext_param, 'to_alipay_dict'):
                params['ext_param'] = self.ext_param.to_alipay_dict()
            else:
                params['ext_param'] = self.ext_param
        if self.line_id:
            if hasattr(self.line_id, 'to_alipay_dict'):
                params['line_id'] = self.line_id.to_alipay_dict()
            else:
                params['line_id'] = self.line_id
        if self.partner_id:
            if hasattr(self.partner_id, 'to_alipay_dict'):
                params['partner_id'] = self.partner_id.to_alipay_dict()
            else:
                params['partner_id'] = self.partner_id
        if self.task_name:
            if hasattr(self.task_name, 'to_alipay_dict'):
                params['task_name'] = self.task_name.to_alipay_dict()
            else:
                params['task_name'] = self.task_name
        if self.time_table_pid:
            if hasattr(self.time_table_pid, 'to_alipay_dict'):
                params['time_table_pid'] = self.time_table_pid.to_alipay_dict()
            else:
                params['time_table_pid'] = self.time_table_pid
        if self.up_bus_cnt:
            if hasattr(self.up_bus_cnt, 'to_alipay_dict'):
                params['up_bus_cnt'] = self.up_bus_cnt.to_alipay_dict()
            else:
                params['up_bus_cnt'] = self.up_bus_cnt
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDataAiserviceCloudbusSchedualtaskAddModel()
        if 'app_version' in d:
            o.app_version = d['app_version']
        if 'city_code' in d:
            o.city_code = d['city_code']
        if 'corp_id' in d:
            o.corp_id = d['corp_id']
        if 'down_bus_cnt' in d:
            o.down_bus_cnt = d['down_bus_cnt']
        if 'ext_param' in d:
            o.ext_param = d['ext_param']
        if 'line_id' in d:
            o.line_id = d['line_id']
        if 'partner_id' in d:
            o.partner_id = d['partner_id']
        if 'task_name' in d:
            o.task_name = d['task_name']
        if 'time_table_pid' in d:
            o.time_table_pid = d['time_table_pid']
        if 'up_bus_cnt' in d:
            o.up_bus_cnt = d['up_bus_cnt']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceLogisticsWaybillInstantdeliverySettleModel(object):

    def __init__(self):
        self._logistics_code = None
        self._order_no = None
        self._out_settle_request_no = None
        self._waybill_no = None
        self._waybill_status = None

    @property
    def logistics_code(self):
        return self._logistics_code

    @logistics_code.setter
    def logistics_code(self, value):
        self._logistics_code = value
    @property
    def order_no(self):
        return self._order_no

    @order_no.setter
    def order_no(self, value):
        self._order_no = value
    @property
    def out_settle_request_no(self):
        return self._out_settle_request_no

    @out_settle_request_no.setter
    def out_settle_request_no(self, value):
        self._out_settle_request_no = value
    @property
    def waybill_no(self):
        return self._waybill_no

    @waybill_no.setter
    def waybill_no(self, value):
        self._waybill_no = value
    @property
    def waybill_status(self):
        return self._waybill_status

    @waybill_status.setter
    def waybill_status(self, value):
        self._waybill_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.logistics_code:
            if hasattr(self.logistics_code, 'to_alipay_dict'):
                params['logistics_code'] = self.logistics_code.to_alipay_dict()
            else:
                params['logistics_code'] = self.logistics_code
        if self.order_no:
            if hasattr(self.order_no, 'to_alipay_dict'):
                params['order_no'] = self.order_no.to_alipay_dict()
            else:
                params['order_no'] = self.order_no
        if self.out_settle_request_no:
            if hasattr(self.out_settle_request_no, 'to_alipay_dict'):
                params['out_settle_request_no'] = self.out_settle_request_no.to_alipay_dict()
            else:
                params['out_settle_request_no'] = self.out_settle_request_no
        if self.waybill_no:
            if hasattr(self.waybill_no, 'to_alipay_dict'):
                params['waybill_no'] = self.waybill_no.to_alipay_dict()
            else:
                params['waybill_no'] = self.waybill_no
        if self.waybill_status:
            if hasattr(self.waybill_status, 'to_alipay_dict'):
                params['waybill_status'] = self.waybill_status.to_alipay_dict()
            else:
                params['waybill_status'] = self.waybill_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceLogisticsWaybillInstantdeliverySettleModel()
        if 'logistics_code' in d:
            o.logistics_code = d['logistics_code']
        if 'order_no' in d:
            o.order_no = d['order_no']
        if 'out_settle_request_no' in d:
            o.out_settle_request_no = d['out_settle_request_no']
        if 'waybill_no' in d:
            o.waybill_no = d['waybill_no']
        if 'waybill_status' in d:
            o.waybill_status = d['waybill_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayUserAccountInfoTaobaoQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayUserAccountInfoTaobaoQueryResponse, self).__init__()
        self._alipay_user_id = None
        self._is_certified = None
        self._login_id = None
        self._user_type = None

    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def is_certified(self):
        return self._is_certified

    @is_certified.setter
    def is_certified(self, value):
        self._is_certified = value
    @property
    def login_id(self):
        return self._login_id

    @login_id.setter
    def login_id(self, value):
        self._login_id = value
    @property
    def user_type(self):
        return self._user_type

    @user_type.setter
    def user_type(self, value):
        self._user_type = value

    def parse_response_content(self, response_content):
        response = super(AlipayUserAccountInfoTaobaoQueryResponse, self).parse_response_content(response_content)
        if 'alipay_user_id' in response:
            self.alipay_user_id = response['alipay_user_id']
        if 'is_certified' in response:
            self.is_certified = response['is_certified']
        if 'login_id' in response:
            self.login_id = response['login_id']
        if 'user_type' in response:
            self.user_type = response['user_type']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.HealthServiceSku import HealthServiceSku
from alipay.aop.api.domain.HealthServiceSku import HealthServiceSku


class HealthServiceItem(object):

    def __init__(self):
        self._item_id = None
        self._item_name = None
        self._merchant_item_bar_code = None
        self._merchant_item_code = None
        self._price = None
        self._sku_list = None
        self._skus = None

    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def merchant_item_bar_code(self):
        return self._merchant_item_bar_code

    @merchant_item_bar_code.setter
    def merchant_item_bar_code(self, value):
        self._merchant_item_bar_code = value
    @property
    def merchant_item_code(self):
        return self._merchant_item_code

    @merchant_item_code.setter
    def merchant_item_code(self, value):
        self._merchant_item_code = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def sku_list(self):
        return self._sku_list

    @sku_list.setter
    def sku_list(self, value):
        if isinstance(value, HealthServiceSku):
            self._sku_list = value
        else:
            self._sku_list = HealthServiceSku.from_alipay_dict(value)
    @property
    def skus(self):
        return self._skus

    @skus.setter
    def skus(self, value):
        if isinstance(value, list):
            self._skus = list()
            for i in value:
                if isinstance(i, HealthServiceSku):
                    self._skus.append(i)
                else:
                    self._skus.append(HealthServiceSku.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.merchant_item_bar_code:
            if hasattr(self.merchant_item_bar_code, 'to_alipay_dict'):
                params['merchant_item_bar_code'] = self.merchant_item_bar_code.to_alipay_dict()
            else:
                params['merchant_item_bar_code'] = self.merchant_item_bar_code
        if self.merchant_item_code:
            if hasattr(self.merchant_item_code, 'to_alipay_dict'):
                params['merchant_item_code'] = self.merchant_item_code.to_alipay_dict()
            else:
                params['merchant_item_code'] = self.merchant_item_code
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.sku_list:
            if hasattr(self.sku_list, 'to_alipay_dict'):
                params['sku_list'] = self.sku_list.to_alipay_dict()
            else:
                params['sku_list'] = self.sku_list
        if self.skus:
            if isinstance(self.skus, list):
                for i in range(0, len(self.skus)):
                    element = self.skus[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.skus[i] = element.to_alipay_dict()
            if hasattr(self.skus, 'to_alipay_dict'):
                params['skus'] = self.skus.to_alipay_dict()
            else:
                params['skus'] = self.skus
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = HealthServiceItem()
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'merchant_item_bar_code' in d:
            o.merchant_item_bar_code = d['merchant_item_bar_code']
        if 'merchant_item_code' in d:
            o.merchant_item_code = d['merchant_item_code']
        if 'price' in d:
            o.price = d['price']
        if 'sku_list' in d:
            o.sku_list = d['sku_list']
        if 'skus' in d:
            o.skus = d['skus']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.LogisticsShopStatusDTO import LogisticsShopStatusDTO


class AlipayOpenInstantdeliveryMerchantshopCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenInstantdeliveryMerchantshopCreateResponse, self).__init__()
        self._logistics_shop_status = None

    @property
    def logistics_shop_status(self):
        return self._logistics_shop_status

    @logistics_shop_status.setter
    def logistics_shop_status(self, value):
        if isinstance(value, list):
            self._logistics_shop_status = list()
            for i in value:
                if isinstance(i, LogisticsShopStatusDTO):
                    self._logistics_shop_status.append(i)
                else:
                    self._logistics_shop_status.append(LogisticsShopStatusDTO.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenInstantdeliveryMerchantshopCreateResponse, self).parse_response_content(response_content)
        if 'logistics_shop_status' in response:
            self.logistics_shop_status = response['logistics_shop_status']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayMerchantOrderHahaNobizcontentCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayMerchantOrderHahaNobizcontentCreateResponse, self).__init__()
        self._out = None

    @property
    def out(self):
        return self._out

    @out.setter
    def out(self, value):
        self._out = value

    def parse_response_content(self, response_content):
        response = super(AlipayMerchantOrderHahaNobizcontentCreateResponse, self).parse_response_content(response_content)
        if 'out' in response:
            self.out = response['out']
